/**
 * Copyright (c) 2018 Gregorius Techneticies
 *
 * This file is part of GregTech.
 *
 * GregTech is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * GregTech is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with GregTech. If not, see <http://www.gnu.org/licenses/>.
 */

package gregapi.load;

import static gregapi.data.CS.*;

import gregapi.data.ANY;
import gregapi.data.CS.ArmorsGT;
import gregapi.data.CS.BlocksGT;
import gregapi.data.CS.ItemsGT;
import gregapi.data.IL;
import gregapi.data.MD;
import gregapi.data.MT;
import gregapi.data.OD;
import gregapi.data.OP;
import gregapi.old.Textures;
import gregapi.oredict.OreDictItemData;
import gregapi.oredict.OreDictManager;
import gregapi.render.IconContainerCopied;
import gregapi.util.OM;
import gregapi.util.ST;
import gregapi.worldgen.StoneLayer;
import net.minecraft.init.Blocks;
import net.minecraft.init.Items;

/**
 * @author Gregorius Techneticies
 * 
 * Loads the ItemList (IL.java) for most Items (everything except the GT ones).
 * This happens during the InitPhase, or if GregTech is installed within the PreInitPhase, since GregTech loads after all the Mods mentioned here, unlike the API.
 */
public class LoaderItemList implements Runnable {
	@Override public String toString() {return "Item List Loader";}
	
	@Override
	public void run() {
		ItemsGT.DEBUG_ITEMS.add(            ST.make(MD.TC, "ItemThaumonomicon"              , 1,42));
		ItemsGT.DEBUG_ITEMS.add(            ST.make(MD.RT, "opSpectreKey"                   , 1, W));
		
		ItemsGT.ILLEGAL_DROPS.add(          ST.make(MD.TC, "ItemThaumonomicon"              , 1,42));
		ItemsGT.ILLEGAL_DROPS.add(          ST.make(MD.RT, "opSpectreKey"                   , 1, W));
		
		ItemsGT.NON_AUTO_INSERT_ITEMS.add(  ST.make(Items.arrow                             , 1, W));
		ItemsGT.NON_AUTO_INSERT_ITEMS.add(  ST.make(Items.fire_charge                       , 1, W));
		ItemsGT.NON_AUTO_INSERT_ITEMS.add(  ST.make(MD.BWM, "bolt"                          , 1, W));
		ItemsGT.NON_AUTO_INSERT_ITEMS.add(  ST.make(MD.BWM, "bullet"                        , 1, W));
		ItemsGT.NON_AUTO_INSERT_ITEMS.add(  ST.make(MD.BWM, "shot"                          , 1, W));
		ItemsGT.NON_AUTO_INSERT_ITEMS.add(  ST.make(MD.BWM, "dart"                          , 1, W));
		ItemsGT.NON_AUTO_INSERT_ITEMS.add(  ST.make(MD.BWM, "dynamite"                      , 1, W));
		ItemsGT.NON_AUTO_INSERT_ITEMS.add(  ST.make(MD.BWM, "cannonball"                    , 1, W));
		
		ItemsGT.AMMO_ITEMS.add(             ST.make(Items.arrow                             , 1, W));
		ItemsGT.AMMO_ITEMS.add(             ST.make(Items.fire_charge                       , 1, W));
		ItemsGT.AMMO_ITEMS.add(             ST.make(MD.BWM, "bolt"                          , 1, W));
		ItemsGT.AMMO_ITEMS.add(             ST.make(MD.BWM, "bullet"                        , 1, W));
		ItemsGT.AMMO_ITEMS.add(             ST.make(MD.BWM, "shot"                          , 1, W));
		ItemsGT.AMMO_ITEMS.add(             ST.make(MD.BWM, "dart"                          , 1, W));
		ItemsGT.AMMO_ITEMS.add(             ST.make(MD.BWM, "dynamite"                      , 1, W));
		ItemsGT.AMMO_ITEMS.add(             ST.make(MD.BWM, "cannonball"                    , 1, W));
		ItemsGT.AMMO_ITEMS.add(             ST.make(MD.TG, "stielGranate"                   , 1, 0));
		ItemsGT.AMMO_ITEMS.add(             ST.make(MD.TG, "fragGrenade"                    , 1, 0));
		ItemsGT.AMMO_ITEMS.add(             ST.make(MD.TG, "TechgunsAmmo"                   , 1, 0));
		ItemsGT.AMMO_ITEMS.add(             ST.make(MD.TG, "TechgunsAmmo"                   , 1, 1));
		ItemsGT.AMMO_ITEMS.add(             ST.make(MD.TG, "TechgunsAmmo"                   , 1, 2));
		ItemsGT.AMMO_ITEMS.add(             ST.make(MD.TG, "TechgunsAmmo"                   , 1, 4));
		ItemsGT.AMMO_ITEMS.add(             ST.make(MD.TG, "TechgunsAmmo"                   , 1, 5));
		ItemsGT.AMMO_ITEMS.add(             ST.make(MD.TG, "TechgunsAmmo"                   , 1, 7));
		ItemsGT.AMMO_ITEMS.add(             ST.make(MD.TG, "TechgunsAmmo"                   , 1, 8));
		ItemsGT.AMMO_ITEMS.add(             ST.make(MD.TG, "TechgunsAmmo"                   , 1,10));
		ItemsGT.AMMO_ITEMS.add(             ST.make(MD.TG, "TechgunsAmmo"                   , 1,12));
		ItemsGT.AMMO_ITEMS.add(             ST.make(MD.TG, "TechgunsAmmo"                   , 1,14));
		ItemsGT.AMMO_ITEMS.add(             ST.make(MD.TG, "TechgunsAmmo"                   , 1,15));
		ItemsGT.AMMO_ITEMS.add(             ST.make(MD.TG, "TechgunsAmmo"                   , 1,17));
		ItemsGT.AMMO_ITEMS.add(             ST.make(MD.TG, "TechgunsAmmo"                   , 1,19));
		ItemsGT.AMMO_ITEMS.add(             ST.make(MD.TG, "TechgunsAmmo"                   , 1,20));
		ItemsGT.AMMO_ITEMS.add(             ST.make(MD.TG, "TechgunsAmmo"                   , 1,22));
		ItemsGT.AMMO_ITEMS.add(             ST.make(MD.TG, "TechgunsAmmo"                   , 1,23));
		ItemsGT.AMMO_ITEMS.add(             ST.make(MD.TG, "TechgunsAmmo"                   , 1,28));
		ItemsGT.AMMO_ITEMS.add(             ST.make(MD.TG, "TechgunsAmmo"                   , 1,46));
		ItemsGT.AMMO_ITEMS.add(             ST.make(MD.TG, "TechgunsAmmo"                   , 1,63));
		ItemsGT.AMMO_ITEMS.add(             ST.make(MD.TG, "TechgunsAmmo"                   , 1,88));
		ItemsGT.AMMO_ITEMS.add(             ST.make(MD.TG, "TechgunsAmmo"                   , 1,93));
		ItemsGT.AMMO_ITEMS.add(             ST.make(MD.TG, "TechgunsAmmo"                   , 1,105));
		ItemsGT.AMMO_ITEMS.add(             ST.make(MD.TG, "TechgunsAmmo"                   , 1,106));
		ItemsGT.AMMO_ITEMS.add(             ST.make(MD.TG, "TechgunsAmmo"                   , 1,107));
		
		ItemsGT.SHOW_RESISTANCE.add(        ST.make(Blocks.dirt                             , 1, W));
		ItemsGT.SHOW_RESISTANCE.add(        ST.make(Blocks.grass                            , 1, W));
		ItemsGT.SHOW_RESISTANCE.add(        ST.make(Blocks.mycelium                         , 1, W));
		ItemsGT.SHOW_RESISTANCE.add(        ST.make(Blocks.gravel                           , 1, W));
		ItemsGT.SHOW_RESISTANCE.add(        ST.make(Blocks.sand                             , 1, W));
		ItemsGT.SHOW_RESISTANCE.add(        ST.make(Blocks.netherrack                       , 1, W));
		ItemsGT.SHOW_RESISTANCE.add(        ST.make(Blocks.nether_brick                     , 1, W));
		ItemsGT.SHOW_RESISTANCE.add(        ST.make(Blocks.end_stone                        , 1, W));
		ItemsGT.SHOW_RESISTANCE.add(        ST.make(Blocks.snow                             , 1, W));
		ItemsGT.SHOW_RESISTANCE.add(        ST.make(Blocks.ice                              , 1, W));
		ItemsGT.SHOW_RESISTANCE.add(        ST.make(Blocks.packed_ice                       , 1, W));
		ItemsGT.SHOW_RESISTANCE.add(        ST.make(Blocks.glowstone                        , 1, W));
		ItemsGT.SHOW_RESISTANCE.add(        ST.make(Blocks.redstone_lamp                    , 1, W));
		ItemsGT.SHOW_RESISTANCE.add(        ST.make(Blocks.quartz_block                     , 1, W));
		ItemsGT.SHOW_RESISTANCE.add(        ST.make(Blocks.wool                             , 1, W));
		ItemsGT.SHOW_RESISTANCE.add(        ST.make(Blocks.glass                            , 1, W));
		ItemsGT.SHOW_RESISTANCE.add(        ST.make(Blocks.stained_glass                    , 1, W));
		ItemsGT.SHOW_RESISTANCE.add(        ST.make(Blocks.clay                             , 1, W));
		ItemsGT.SHOW_RESISTANCE.add(        ST.make(Blocks.hardened_clay                    , 1, W));
		ItemsGT.SHOW_RESISTANCE.add(        ST.make(Blocks.stained_hardened_clay            , 1, W));
		ItemsGT.SHOW_RESISTANCE.add(        ST.make(Blocks.leaves                           , 1, W));
		ItemsGT.SHOW_RESISTANCE.add(        ST.make(Blocks.leaves2                          , 1, W));
		ItemsGT.SHOW_RESISTANCE.add(        ST.make(Blocks.planks                           , 1, W));
		ItemsGT.SHOW_RESISTANCE.add(        ST.make(Blocks.log                              , 1, W));
		ItemsGT.SHOW_RESISTANCE.add(        ST.make(Blocks.log2                             , 1, W));
		ItemsGT.SHOW_RESISTANCE.add(        ST.make(Blocks.sandstone                        , 1, W));
		ItemsGT.SHOW_RESISTANCE.add(        ST.make(Blocks.stone                            , 1, W));
		ItemsGT.SHOW_RESISTANCE.add(        ST.make(Blocks.cobblestone                      , 1, W));
		ItemsGT.SHOW_RESISTANCE.add(        ST.make(Blocks.mossy_cobblestone                , 1, W));
		ItemsGT.SHOW_RESISTANCE.add(        ST.make(Blocks.stonebrick                       , 1, W));
		ItemsGT.SHOW_RESISTANCE.add(        ST.make(Blocks.brick_block                      , 1, W));
		ItemsGT.SHOW_RESISTANCE.add(        ST.make(Blocks.obsidian                         , 1, W));
		ItemsGT.SHOW_RESISTANCE.add(        ST.make(Blocks.bedrock                          , 1, W));
		ItemsGT.SHOW_RESISTANCE.add(        ST.make(MD.BTL, "bedrock"                       , 1, W));
		ItemsGT.SHOW_RESISTANCE.add(        ST.make(MD.OMT, "hardWallTierOne"               , 1, W));
		ItemsGT.SHOW_RESISTANCE.add(        ST.make(MD.OMT, "hardWallTierTwo"               , 1, W));
		ItemsGT.SHOW_RESISTANCE.add(        ST.make(MD.OMT, "hardWallTierThree"             , 1, W));
		ItemsGT.SHOW_RESISTANCE.add(        ST.make(MD.OMT, "hardWallTierFour"              , 1, W));
		ItemsGT.SHOW_RESISTANCE.add(        ST.make(MD.OMT, "hardWallTierFive"              , 1, W));
		ItemsGT.SHOW_RESISTANCE.add(        ST.mkic("reinforcedGlass"                       , 1));
		ItemsGT.SHOW_RESISTANCE.add(        ST.mkic("reinforcedStone"                       , 1));
		ItemsGT.SHOW_RESISTANCE.add(        ST.mkic("constructionFoamWall"                  , 1));
		ItemsGT.SHOW_RESISTANCE.add(        ST.make(MD.TG, "container"                      , 1, W));
		ItemsGT.SHOW_RESISTANCE.add(        ST.make(MD.TG, "metalpanel"                     , 1, W));
		ItemsGT.SHOW_RESISTANCE.add(        ST.make(MD.TG, "metalpanel2"                    , 1, W));
		ItemsGT.SHOW_RESISTANCE.add(        ST.make(MD.TG, "concrete"                       , 1, W));
		ItemsGT.SHOW_RESISTANCE.add(        ST.make(MD.HBM, "tile.reinforced_brick"         , 1, W));
		ItemsGT.SHOW_RESISTANCE.add(        ST.make(MD.HBM, "tile.reinforced_light"         , 1, W));
		ItemsGT.SHOW_RESISTANCE.add(        ST.make(MD.HBM, "tile.reinforced_glass"         , 1, W));
		ItemsGT.SHOW_RESISTANCE.add(        ST.make(MD.HBM, "tile.asphalt"                  , 1, W));
		ItemsGT.SHOW_RESISTANCE.add(        ST.make(MD.HBM, "tile.brick_concrete"           , 1, W));
		ItemsGT.SHOW_RESISTANCE.add(        ST.make(MD.HBM, "tile.brick_obsidian"           , 1, W));
		ItemsGT.SHOW_RESISTANCE.add(        ST.make(MD.HBM, "tile.gravel_obsidian"          , 1, W));
		ItemsGT.SHOW_RESISTANCE.add(        ST.make(MD.HBM, "tile.cmb_brick"                , 1, W));
		ItemsGT.SHOW_RESISTANCE.add(        ST.make(MD.HBM, "tile.cmb_brick_reinforced"     , 1, W));
		ItemsGT.SHOW_RESISTANCE.add(        ST.make(MD.HBM, "tile.factory_titanium_hull"    , 1, W));
		ItemsGT.SHOW_RESISTANCE.add(        ST.make(MD.HBM, "tile.factory_advanced_hull"    , 1, W));
		ItemsGT.SHOW_RESISTANCE.add(        ST.make(MD.HBM, "tile.block_meteor_cobble"      , 1, W));
		ItemsGT.SHOW_RESISTANCE.add(        ST.make(MD.HBM, "tile.crystal_hardened"         , 1, W));
		ItemsGT.SHOW_RESISTANCE.add(        ST.make(MD.TC, "blockWarded"                    , 1, W));
		ItemsGT.SHOW_RESISTANCE.add(        ST.make(MD.ICBM, "icbmCConcrete"                , 1, W));
		ItemsGT.SHOW_RESISTANCE.add(        ST.make(MD.ICBM, "icbmCRail"                    , 1, W));
		ItemsGT.SHOW_RESISTANCE.add(        ST.make(MD.ICBM, "icbmCGlass"                   , 1, W));
		ItemsGT.SHOW_RESISTANCE.add(        ST.make(MD.ICBM, "icbmCCamouflage"              , 1, W));
		
		
		BlocksGT.harvestableSpade.add(ST.block(MD.EB, "enhancedbiomes.tile.dirtEB"));
		BlocksGT.harvestableSpade.add(ST.block(MD.EB, "enhancedbiomes.tile.grassEB"));
		BlocksGT.harvestableSpade.add(ST.block(MD.BoP, "mud"));
		BlocksGT.harvestableSpade.add(ST.block(MD.BoP, "driedDirt"));
		BlocksGT.harvestableSpade.add(ST.block(MD.BoP, "originGrass"));
		BlocksGT.harvestableSpade.add(ST.block(MD.BoP, "longGrass"));
		BlocksGT.harvestableSpade.add(ST.block(MD.BoP, "bopGrass"));
		BlocksGT.harvestableSpade.add(ST.block(MD.BoP, "newBopDirt"));
		BlocksGT.harvestableSpade.add(ST.block(MD.BoP, "newBopGrass"));
		BlocksGT.harvestableSpade.add(ST.block(MD.BoP, "overgrownNetherrack"));
		BlocksGT.harvestableSpade.add(ST.block(MD.ERE, "mud"));
		BlocksGT.harvestableSpade.add(ST.block(MD.BTL, "mud"));
		BlocksGT.harvestableSpade.add(ST.block(MD.BTL, "swampDirt"));
		BlocksGT.harvestableSpade.add(ST.block(MD.BTL, "swampGrass"));
		BlocksGT.harvestableSpade.add(ST.block(MD.BTL, "deadGrass"));
		BlocksGT.harvestableSpade.add(ST.block(MD.BTL, "slimyGrass"));
		BlocksGT.harvestableSpade.add(ST.block(MD.BOTA, "altGrass"));
		BlocksGT.harvestableSpade.add(ST.block(MD.AETHER, "aetherDirt"));
		BlocksGT.harvestableSpade.add(ST.block(MD.AETHER, "aetherGrass"));
		BlocksGT.harvestableSpade.add(ST.block(MD.AETHER, "enchantedAetherGrass"));
		BlocksGT.harvestableSpade.add(ST.block(MD.AETHER, "enchantedGrass"));
		
		BlocksGT.plantableGreens.add(ST.block(MD.EB, "enhancedbiomes.tile.dirtEB"));
		BlocksGT.plantableGreens.add(ST.block(MD.EB, "enhancedbiomes.tile.grassEB"));
		BlocksGT.plantableGreens.add(ST.block(MD.BoP, "mud"));
		BlocksGT.plantableGreens.add(ST.block(MD.BoP, "originGrass"));
		BlocksGT.plantableGreens.add(ST.block(MD.BoP, "longGrass"));
		BlocksGT.plantableGreens.add(ST.block(MD.BoP, "bopGrass"));
		BlocksGT.plantableGreens.add(ST.block(MD.BoP, "newBopDirt"));
		BlocksGT.plantableGreens.add(ST.block(MD.BoP, "newBopGrass"));
		BlocksGT.plantableGreens.add(ST.block(MD.ERE, "mud"));
		BlocksGT.plantableGreens.add(ST.block(MD.BTL, "mud"));
		BlocksGT.plantableGreens.add(ST.block(MD.BTL, "swampDirt"));
		BlocksGT.plantableGreens.add(ST.block(MD.BTL, "swampGrass"));
		BlocksGT.plantableGreens.add(ST.block(MD.BTL, "slimyGrass"));
		BlocksGT.plantableGreens.add(ST.block(MD.BOTA, "altGrass"));
		BlocksGT.plantableGreens.add(ST.block(MD.AETHER, "aetherDirt"));
		BlocksGT.plantableGreens.add(ST.block(MD.AETHER, "aetherGrass"));
		BlocksGT.plantableGreens.add(ST.block(MD.AETHER, "enchantedAetherGrass"));
		BlocksGT.plantableGreens.add(ST.block(MD.AETHER, "enchantedGrass"));
		
		BlocksGT.plantableGrass.add(ST.block(MD.EB, "enhancedbiomes.tile.grassEB"));
		BlocksGT.plantableGrass.add(ST.block(MD.BoP, "originGrass"));
		BlocksGT.plantableGrass.add(ST.block(MD.BoP, "longGrass"));
		BlocksGT.plantableGrass.add(ST.block(MD.BoP, "bopGrass"));
		BlocksGT.plantableGrass.add(ST.block(MD.BoP, "newBopGrass"));
		BlocksGT.plantableGrass.add(ST.block(MD.BTL, "swampGrass"));
		BlocksGT.plantableGrass.add(ST.block(MD.BTL, "slimyGrass"));
		BlocksGT.plantableGrass.add(ST.block(MD.BOTA, "altGrass"));
		BlocksGT.plantableGrass.add(ST.block(MD.AETHER, "aetherGrass"));
		BlocksGT.plantableGrass.add(ST.block(MD.AETHER, "enchantedAetherGrass"));
		BlocksGT.plantableGrass.add(ST.block(MD.AETHER, "enchantedGrass"));
		
		
		StoneLayer.REPLACEABLE_BLOCKS.add(ST.block(MD.UB, "igneousStone"));
		StoneLayer.REPLACEABLE_BLOCKS.add(ST.block(MD.UB, "metamorphicStone"));
		StoneLayer.REPLACEABLE_BLOCKS.add(ST.block(MD.UB, "sedimentaryStone"));
		StoneLayer.REPLACEABLE_BLOCKS.add(ST.block(MD.UB, "igneousCobblestone"));
		StoneLayer.REPLACEABLE_BLOCKS.add(ST.block(MD.UB, "metamorphicCobblestone"));
		StoneLayer.REPLACEABLE_BLOCKS.add(ST.block(MD.PFAA, "weakStone"));
		StoneLayer.REPLACEABLE_BLOCKS.add(ST.block(MD.PFAA, "mediumStone"));
		StoneLayer.REPLACEABLE_BLOCKS.add(ST.block(MD.PFAA, "strongStone"));
		StoneLayer.REPLACEABLE_BLOCKS.add(ST.block(MD.PFAA, "veryStrongStone"));
		StoneLayer.REPLACEABLE_BLOCKS.add(ST.block(MD.PFAA, "weakRubble"));
		StoneLayer.REPLACEABLE_BLOCKS.add(ST.block(MD.PFAA, "mediumCobble"));
		StoneLayer.REPLACEABLE_BLOCKS.add(ST.block(MD.PFAA, "strongCobble"));
		StoneLayer.REPLACEABLE_BLOCKS.add(ST.block(MD.PFAA, "veryStrongCobble"));
		StoneLayer.REPLACEABLE_BLOCKS.add(ST.block(MD.CHSL, "granite"));
		StoneLayer.REPLACEABLE_BLOCKS.add(ST.block(MD.CHSL, "diorite"));
		StoneLayer.REPLACEABLE_BLOCKS.add(ST.block(MD.CHSL, "andesite"));
		StoneLayer.REPLACEABLE_BLOCKS.add(ST.block(MD.CHSL, "marble"));
		StoneLayer.REPLACEABLE_BLOCKS.add(ST.block(MD.CHSL, "limestone"));
		StoneLayer.REPLACEABLE_BLOCKS.add(ST.block(MD.EtFu, "stone"));
		StoneLayer.REPLACEABLE_BLOCKS.add(ST.block(MD.GaSu, "18Stones"));
		StoneLayer.REPLACEABLE_BLOCKS.add(ST.block(MD.GaSu, "basalt"));
		StoneLayer.REPLACEABLE_BLOCKS.add(ST.block(MD.BOTA, "stone"));
		StoneLayer.REPLACEABLE_BLOCKS.add(ST.block(MD.IC2, "blockOreCopper"));
		StoneLayer.REPLACEABLE_BLOCKS.add(ST.block(MD.IC2, "blockOreLead"));
		StoneLayer.REPLACEABLE_BLOCKS.add(ST.block(MD.IC2, "blockOreTin"));
		StoneLayer.REPLACEABLE_BLOCKS.add(ST.block(MD.IC2, "blockOreUran"));
		StoneLayer.REPLACEABLE_BLOCKS.add(ST.block(MD.TG, "oreTitanIron"));
		StoneLayer.REPLACEABLE_BLOCKS.add(ST.block(MD.BR, "YelloriteOre"));
		StoneLayer.REPLACEABLE_BLOCKS.add(ST.block(MD.BoP, "gemOre"));
		StoneLayer.REPLACEABLE_BLOCKS.add(ST.block(MD.BoP, "rocks"));
		StoneLayer.REPLACEABLE_BLOCKS.add(ST.block(MD.EB, "enhancedbiomes.tile.stoneEB"));
		StoneLayer.REPLACEABLE_BLOCKS.add(ST.block(MD.EB, "enhancedbiomes.tile.stoneCobbleEB"));
		StoneLayer.REPLACEABLE_BLOCKS.add(ST.block(MD.FR, "resources"));
		StoneLayer.REPLACEABLE_BLOCKS.add(ST.block(MD.GC, "tile.gcBlockCore"));
		StoneLayer.REPLACEABLE_BLOCKS.add(ST.block(MD.GC_GALAXYSPACE, "leadore"));
		StoneLayer.REPLACEABLE_BLOCKS.add(ST.block(MD.IE, "ore"));
		StoneLayer.REPLACEABLE_BLOCKS.add(ST.block(MD.TC, "blockCustomOre"));
		StoneLayer.REPLACEABLE_BLOCKS.add(ST.block(MD.TE_FOUNDATION, "Ore"));
		StoneLayer.REPLACEABLE_BLOCKS.add(ST.block(MD.ENVM, "flammablecoal"));
		StoneLayer.REPLACEABLE_BLOCKS.add(ST.block(MD.HaC, "salt"));
		StoneLayer.REPLACEABLE_BLOCKS.add(ST.block(MD.VULPES, "libVulpesore0"));
		StoneLayer.REPLACEABLE_BLOCKS.add(ST.block(MD.BP, "ruby_ore"));
		StoneLayer.REPLACEABLE_BLOCKS.add(ST.block(MD.BP, "sapphire_ore"));
		StoneLayer.REPLACEABLE_BLOCKS.add(ST.block(MD.BP, "amethyst_ore"));
		StoneLayer.REPLACEABLE_BLOCKS.add(ST.block(MD.BP, "silver_ore"));
		StoneLayer.REPLACEABLE_BLOCKS.add(ST.block(MD.BP, "teslatite_ore"));
		StoneLayer.REPLACEABLE_BLOCKS.add(ST.block(MD.BP, "tungsten_ore"));
		StoneLayer.REPLACEABLE_BLOCKS.add(ST.block(MD.BP, "zinc_ore"));
		StoneLayer.REPLACEABLE_BLOCKS.add(ST.block(MD.BP, "copper_ore"));
		StoneLayer.REPLACEABLE_BLOCKS.add(ST.block(MD.MgC, "copper_ore"));
		StoneLayer.REPLACEABLE_BLOCKS.add(ST.block(MD.MgC, "uranium_ore"));
		StoneLayer.REPLACEABLE_BLOCKS.add(ST.block(MD.MgC, "sulfur_ore"));
		StoneLayer.REPLACEABLE_BLOCKS.add(ST.block(MD.MgC, "salt_ore"));
		StoneLayer.REPLACEABLE_BLOCKS.add(ST.block(MD.MgC, "tungsten_ore"));
		StoneLayer.REPLACEABLE_BLOCKS.add(ST.block(MD.MgC, "zinc_ore"));
		StoneLayer.REPLACEABLE_BLOCKS.add(ST.block(MD.MgC, "thorium_ore"));
		
		
		IL.Bottle_Empty                         .set(ST.make(Items.glass_bottle, 1, 0));
		
		IL.Dye_Bonemeal                         .set(ST.make(Items.dye, 1, 15));
		IL.Dye_SquidInk                         .set(ST.make(Items.dye, 1, 0));
		IL.Dye_Cactus                           .set(ST.make(Items.dye, 1, 2));
		IL.Dye_Cocoa                            .set(ST.make(Items.dye, 1, 3), null, "cropCocoa");
		
		IL.Bale_Wheat                           .set(ST.make(Blocks.hay_block, 1, 0), null, "baleWheat");
		IL.Crop_Wheat                           .set(ST.make(Items.wheat, 1, 0), null, "cropWheat");
		IL.Food_Bread                           .set(ST.make(Items.bread, 1, 0));
		IL.Food_Carrot                          .set(ST.make(Items.carrot, 1, 0), null, "cropCarrot");
		IL.Food_Potato                          .set(ST.make(Items.potato, 1, 0), null, "cropPotato");
		IL.Food_Potato_Baked                    .set(ST.make(Items.baked_potato, 1, 0));
		IL.Food_Potato_Poisonous                .set(ST.make(Items.poisonous_potato, 1, 0));
		
		IL.TE_Cinnabar                          .set(ST.make(MD.TE_FOUNDATION, "material"                   , 1,  20), new OreDictItemData(MT.OREMATS.Cinnabar, U));
		IL.TE_Rod_Blizz                         .set(ST.make(MD.TE_FOUNDATION, "material"                   , 1,1024), new OreDictItemData(MT.Blizz, U*2));
		IL.TE_Rod_Blitz                         .set(ST.make(MD.TE_FOUNDATION, "material"                   , 1,1026), new OreDictItemData(MT.Blitz, U*2));
		IL.TE_Rod_Basalz                        .set(ST.make(MD.TE_FOUNDATION, "material"                   , 1,1028), new OreDictItemData(MT.Basalz, U*2));
		IL.TE_Slag                              .set(ST.make(MD.TE, "material"                              , 1, 514), null, OD.itemSlag);
		IL.TE_Slag_Rich                         .set(ST.make(MD.TE, "material"                              , 1, 515), null, OD.itemSlag);
		IL.TE_Phyto_Gro                         .set(ST.make(MD.TE, "material"                              , 1, 516), null, OD.itemFertilizer);
		IL.TE_Phyto_Gro_Rich                    .set(ST.make(MD.TE, "material"                              , 1, 517), null, OD.itemFertilizer);
		IL.TE_Rockwool                          .set(ST.make(MD.TE, "Rockwool"                              , 1,   0));
		
		IL.RC_ShuntingWire                      .set(ST.make(MD.RC, "machine.delta"                         , 1, 0));
		IL.RC_ShuntingWireFrame                 .set(ST.make(MD.RC, "frame"                                 , 1, 0));
		IL.RC_Post_Metal                        .set(ST.make(MD.RC, "post"                                  , 1, 2));
		IL.RC_Concrete                          .set(ST.make(MD.RC, "cube"                                  , 1, 1), new OreDictItemData(MT.Stone, 5*U8));
		IL.RC_Crushed_Obsidian                  .set(ST.make(MD.RC, "cube"                                  , 1, 4), new OreDictItemData(MT.Obsidian, U*8));
		IL.RC_Stone_Abyssal                     .set(ST.make(MD.RC, "cube"                                  , 1, 6), OP.stone.dat(MT.Basalt));
		IL.RC_Stone_Quarried                    .set(ST.make(MD.RC, "cube"                                  , 1, 7), OP.stone.dat(MT.Marble));
		IL.RC_Creosote_Wood                     .set(ST.make(MD.RC, "cube"                                  , 1, 8), new OreDictItemData(ANY.Wood, U*8));
		IL.RC_Rail_Standard                     .set(ST.make(MD.RC, "part.rail"                             , 1, 0));
		IL.RC_Rail_Adv                          .set(ST.make(MD.RC, "part.rail"                             , 1, 1));
		IL.RC_Rail_Wooden                       .set(ST.make(MD.RC, "part.rail"                             , 1, 2));
		IL.RC_Rail_HS                           .set(ST.make(MD.RC, "part.rail"                             , 1, 3));
		IL.RC_Rail_Reinforced                   .set(ST.make(MD.RC, "part.rail"                             , 1, 4));
		IL.RC_Rail_Electric                     .set(ST.make(MD.RC, "part.rail"                             , 1, 5));
		IL.RC_Tie_Wood                          .set(ST.make(MD.RC, "part.tie"                              , 1, 0), new OreDictItemData(ANY.Wood, 3*U2));
		IL.RC_Tie_Stone                         .set(ST.make(MD.RC, "part.tie"                              , 1, 1), new OreDictItemData(MT.Stone, 3*U2));
		IL.RC_Bed_Wood                          .set(ST.make(MD.RC, "part.railbed"                          , 1, 0), new OreDictItemData(ANY.Wood, U*6));
		IL.RC_Bed_Stone                         .set(ST.make(MD.RC, "part.railbed"                          , 1, 1), new OreDictItemData(MT.Stone, U*6));
		IL.RC_Rebar                             .set(ST.make(MD.RC, "part.rebar"                            , 1, 0));
		
		IL.RC_Crowbar_Iron                      .set(ST.make(MD.RC, "tool.crowbar"                          , 1, 0), new OreDictItemData(ANY.Fe, U*3));
		IL.RC_Crowbar_Steel                     .set(ST.make(MD.RC, "tool.crowbar.reinforced"               , 1, 0), new OreDictItemData(ANY.Steel, U*3));
		IL.RC_Crowbar_Thaumium                  .set(ST.make(MD.RC, "tool.crowbar.magic"                    , 1, 0), new OreDictItemData(MT.Thaumium, U*3));
		IL.RC_Crowbar_Voidmetal                 .set(ST.make(MD.RC, "tool.crowbar.void"                     , 1, 0), new OreDictItemData(MT.VoidMetal, U*3));
		
		IL.Tool_Sword_Steel                     .set(ST.make(MD.RC, "tool.steel.sword"                      , 1, 0));
		IL.Tool_Pickaxe_Steel                   .set(ST.make(MD.RC, "tool.steel.pickaxe"                    , 1, 0));
		IL.Tool_Shovel_Steel                    .set(ST.make(MD.RC, "tool.steel.shovel"                     , 1, 0));
		IL.Tool_Axe_Steel                       .set(ST.make(MD.RC, "tool.steel.axe"                        , 1, 0));
		IL.Tool_Hoe_Steel                       .set(ST.make(MD.RC, "tool.steel.hoe"                        , 1, 0));
		
		IL.RC_Creosote_Bottle                   .set(ST.make(MD.RC, "fluid.creosote.bottle"                 , 1, 0), null, "bottleCreosote", OD.container1000creosote);
		IL.RC_Creosote_Bucket                   .set(ST.make(MD.RC, "fluid.creosote.bucket"                 , 1, 0), null, "bucketCreosote");
		IL.RC_Creosote_Can                      .set(ST.make(MD.RC, "fluid.creosote.can"                    , 1, 0), null, OD.container1000creosote);
		IL.RC_Creosote_Capsule                  .set(ST.make(MD.RC, "fluid.creosote.wax"                    , 1, 0), null, OD.container1000creosote);
		IL.RC_Creosote_RefractoryCapsule        .set(ST.make(MD.RC, "fluid.creosote.refactory"              , 1, 0), null, OD.container1000creosote);
		
		if (IL.RC_Creosote_Bottle.item() != null) IL.RC_Creosote_Bottle.item().setContainerItem(Items.glass_bottle);
		
		IL.IE_Creosote_Bottle                   .set(ST.make(MD.IE, "fluidContainers"                       , 1, 0), null, "bottleCreosote", OD.container1000creosote);
		IL.IE_Creosote_Bucket                   .set(ST.make(MD.IE, "fluidContainers"                       , 1, 1), null, "bucketCreosote");
		IL.IE_Hammer                            .set(ST.make(MD.IE, "tool"                                  , 1, 0), new OreDictItemData(ANY.Fe, 2*U, ANY.Wood, U));
		IL.IE_Slag                              .set(ST.make(MD.IE, "material"                              , 1,13), null, OD.itemSlag);
		IL.IE_Blueprint_Projectiles_Common      .set(ST.make(MD.IE, "blueprint"                             , 1, 0), new OreDictItemData(MT.Paper, 3*U));
		IL.IE_Blueprint_Projectiles_Specialized .set(ST.make(MD.IE, "blueprint"                             , 1, 1), new OreDictItemData(MT.Paper, 3*U));
		IL.IE_Blueprint_Projectiles_Electrodes  .set(ST.make(MD.IE, "blueprint"                             , 1, 2), new OreDictItemData(MT.Paper, 3*U));
		IL.IE_Treated_Planks                    .set(ST.make(MD.IE, "treatedWood"                           , 1, 0), new OreDictItemData(MT.WoodSealed, U));
		IL.IE_Treated_Slab                      .set(ST.make(MD.IE, "woodenDecoration"                      , 1, 2), new OreDictItemData(MT.WoodSealed, U2));
		IL.IE_Treated_Stairs                    .set(ST.make(MD.IE, "woodenStairs"                          , 1, 0), new OreDictItemData(MT.WoodSealed, 3*U4));
		IL.IE_Crate                             .set(ST.make(MD.IE, "woodenDevice"                          , 1, 4), new OreDictItemData(MT.WoodSealed, 8*U), OD.craftingChest);
		
		IL.Myst_Ink_Vial                        .set(ST.make(MD.MYST, "vial"                                , 1, 0));
		IL.Myst_Desk_Item                       .set(ST.make(MD.MYST, "writingdesk"                         , 1, 0));
		IL.Myst_Desk_Block                      .set(ST.make(MD.MYST, "WritingDesk"                         , 1, 0)); // 0L and 8R X POS, 1L and 9R Z NEG, 2L and 10R X NEG, 3L and 11R Z POS
		IL.Myst_Bookstand                       .set(ST.make(MD.MYST, "BlockBookstand"                      , 1, 0)); // Requires Rotation Calls
		IL.Myst_Lectern                         .set(ST.make(MD.MYST, "BlockLectern"                        , 1, 0)); // Requires Rotation Calls
		IL.Myst_Receptacle                      .set(ST.make(MD.MYST, "BlockBookReceptacle"                 , 1, 0)); // Front is using vanilla siding
		IL.Myst_Crystal                         .set(ST.make(MD.MYST, "BlockCrystal"                        , 1, 0));
		IL.Myst_Ink_Mixer                       .set(ST.make(MD.MYST, "BlockInkMixer"                       , 1, 0)); // Requires Rotation Calls
		IL.Myst_Book_Binder                     .set(ST.make(MD.MYST, "BlockBookBinder"                     , 1, 0)); // Requires Rotation Calls
		
		IL.BOTA_Ender_Air_Bottle                .set(ST.make(MD.BOTA, "manaResource"                        , 1,15));
		IL.BOTA_Paintslinger                    .set(ST.make(MD.BOTA, "lens"                                , 1,14));
		
		IL.TC_Nugget_Beef                       .set(ST.make(MD.TC, "ItemNuggetBeef"                        , 1, 0), new OreDictItemData(MT.MeatCooked, U9));
		IL.TC_Nugget_Chicken                    .set(ST.make(MD.TC, "ItemNuggetChicken"                     , 1, 0), new OreDictItemData(MT.MeatCooked, U9));
		IL.TC_Nugget_Fish                       .set(ST.make(MD.TC, "ItemNuggetFish"                        , 1, 0), new OreDictItemData(MT.FishCooked, U9));
		IL.TC_Nugget_Pork                       .set(ST.make(MD.TC, "ItemNuggetPork"                        , 1, 0), new OreDictItemData(MT.MeatCooked, U9));
		IL.TC_Triple_Meat_Treat                 .set(ST.make(MD.TC, "TripleMeatTreat"                       , 1, 0), new OreDictItemData(MT.MeatCooked, U3));
		IL.TC_Greatwood_Log                     .set(ST.make(MD.TC, "blockMagicalLog"                       , 1, 0), new OreDictItemData(MT.Greatwood , U * 8, MT.Bark, U), OD.logWood);
		IL.TC_Silverwood_Log                    .set(ST.make(MD.TC, "blockMagicalLog"                       , 1, 1), new OreDictItemData(MT.Silverwood, U * 8, MT.Bark, U), OD.logWood);
		IL.TC_Greatwood_Planks                  .set(ST.make(MD.TC, "blockWoodenDevice"                     , 1, 6), new OreDictItemData(MT.Greatwood , U), OP.plank.dat(MT.Greatwood));
		IL.TC_Silverwood_Planks                 .set(ST.make(MD.TC, "blockWoodenDevice"                     , 1, 7), new OreDictItemData(MT.Silverwood, U), OP.plank.dat(MT.Silverwood));
		IL.TC_Shimmerleaf                       .set(ST.make(MD.TC, "blockCustomPlant"                      , 1, 2), new OreDictItemData(MT.Hg, U), "flowerShimmerleaf");
		IL.TC_Cinderpearl                       .set(ST.make(MD.TC, "blockCustomPlant"                      , 1, 3), new OreDictItemData(MT.Blaze, U), "flowerCinderpearl");
		IL.TC_Vishroom                          .set(ST.make(MD.TC, "blockCustomPlant"                      , 1, 5));
		IL.TC_Block_Amber                       .set(ST.make(MD.TC, "blockCosmeticOpaque"                   , 1, 0), new OreDictItemData(MT.Amber, 4*U));
		IL.TC_Block_Amber_Bricks                .set(ST.make(MD.TC, "blockCosmeticOpaque"                   , 1, 1), new OreDictItemData(MT.Amber, 4*U));
		IL.TC_Warded_Glass                      .set(ST.make(MD.TC, "blockCosmeticOpaque"                   , 1, 2));
		IL.TC_Thaumometer                       .set(ST.make(MD.TC, "ItemThaumometer"                       , 1, 0));
		IL.TC_Alumentum                         .set(ST.make(MD.TC, "ItemResource"                          , 1, 0));
		IL.TC_Nitor                             .set(ST.make(MD.TC, "ItemResource"                          , 1, 1));
		IL.TC_Tallow                            .set(ST.make(MD.TC, "ItemResource"                          , 1, 4), new OreDictItemData(MT.Tallow, U));
		IL.TC_Block_Tallow                      .set(ST.make(MD.TC, "blockCosmeticSolid"                    , 1, 5), new OreDictItemData(MT.Tallow, 9*U));
		IL.TC_Block_Flesh                       .set(ST.make(MD.TC, "blockTaint"                            , 1, 2), new OreDictItemData(MT.MeatRotten, 18*U, MT.Bone, U));
		IL.TC_Block_Air                         .set(ST.make(MD.TC, "blockAiry"                             , 1, 0));
		IL.TC_Phial                             .set(ST.make(MD.TC, "ItemEssence"                           , 1, 0), new OreDictItemData(ANY.Clay, U8, MT.Glass, 3*U8));
		IL.TC_Thaumonomicon                     .set(ST.make(MD.TC, "ItemThaumonomicon"                     , 1, 0), new OreDictItemData(MT.Paper, 9*U));
		IL.TC_Crimson_Rites                     .set(ST.make(MD.TC, "ItemEldritchObject"                    , 1, 1), new OreDictItemData(MT.Paper, 9*U));
		
		IL.TF_LiveRoot                          .set(ST.make(MD.TF, "item.liveRoot"                         , 1, 0), new OreDictItemData(MT.LiveRoot, U));
		IL.TF_Torchberries                      .set(ST.make(MD.TF, "item.torchberries"                     , 1, 0));
		IL.TF_NagaScale                         .set(ST.make(MD.TF, "item.nagaScale"                        , 1, 0));
		IL.TF_BorerEssence                      .set(ST.make(MD.TF, "item.borerEssence"                     , 1, 0));
		IL.TF_Carminite                         .set(ST.make(MD.TF, "item.carminite"                        , 1, 0));
		IL.TF_Vial_FieryBlood                   .set(ST.make(MD.TF, "item.fieryBlood"                       , 1, 0));
		IL.TF_Vial_FieryTears                   .set(ST.make(MD.TF, "item.fieryTears"                       , 1, 0));
		IL.TF_Hydrachop_Raw                     .set(ST.make(MD.TF, "item.hydraChop"                        , 1, 0), new OreDictItemData(MT.MeatRaw             , U*8, MT.Bone,U*2), "listAllhydraraw");
		IL.TF_Meef_Raw                          .set(ST.make(MD.TF, "item.meefRaw"                          , 1, 0), new OreDictItemData(MT.MeatRaw             , U*2, MT.Bone, U9), "listAllbeefraw");
		IL.TF_Meef_Cooked                       .set(ST.make(MD.TF, "item.meefSteak"                        , 1, 0), new OreDictItemData(MT.MeatCooked          , U*2, MT.Bone, U9), "listAllbeefcooked");
		IL.TF_Venison_Raw                       .set(ST.make(MD.TF, "item.venisonRaw"                       , 1, 0), new OreDictItemData(MT.MeatRaw             , U*2, MT.Bone, U9), "foodVenisonraw");
		IL.TF_Venison_Cooked                    .set(ST.make(MD.TF, "item.venisonCooked"                    , 1, 0), new OreDictItemData(MT.MeatCooked          , U*2, MT.Bone, U9), "foodVenisoncooked");
		IL.TF_Fiddlehead                        .set(ST.make(MD.TF, "tile.TFPlant"                          , 1, 8));
		IL.TF_Mushgloom                         .set(ST.make(MD.TF, "tile.TFPlant"                          , 1, 9), new OreDictItemData(ANY.Glowstone, U4), OD.listAllmushroom);
		IL.TF_Tall_Grass                        .set(ST.make(MD.TF, "tile.TFPlant"                          , 1,10), null, OD.itemGrassTall);
		IL.TF_Dry_Bush                          .set(ST.make(MD.TF, "tile.TFPlant"                          , 1,11));
		IL.TF_Log_Oak                           .set(ST.make(MD.TF, "tile.TFLog"                            , 1, 0), new OreDictItemData(MT.Wood, U*8, MT.Bark, U), OD.logWood);
		IL.TF_Log_Canopy                        .set(ST.make(MD.TF, "tile.TFLog"                            , 1, 1), new OreDictItemData(MT.Wood, U*8, MT.Bark, U), OD.logWood);
		IL.TF_Log_Mangrove                      .set(ST.make(MD.TF, "tile.TFLog"                            , 1, 2), new OreDictItemData(MT.Wood, U*8, MT.Bark, U), OD.logWood);
		IL.TF_Log_Darkwood                      .set(ST.make(MD.TF, "tile.TFLog"                            , 1, 3), new OreDictItemData(MT.Wood, U*8, MT.Bark, U), OD.logWood);
		IL.TF_Log_Time                          .set(ST.make(MD.TF, "tile.TFMagicLog"                       , 1, 0), new OreDictItemData(MT.Wood, U*8, MT.Bark, U), OD.logWood);
		IL.TF_Log_Trans                         .set(ST.make(MD.TF, "tile.TFMagicLog"                       , 1, 1), new OreDictItemData(MT.Wood, U*8, MT.Bark, U), OD.logWood);
		IL.TF_Log_Mine                          .set(ST.make(MD.TF, "tile.TFMagicLog"                       , 1, 2), new OreDictItemData(MT.Wood, U*8, MT.Bark, U), OD.logWood);
		IL.TF_Log_Sorting                       .set(ST.make(MD.TF, "tile.TFMagicLog"                       , 1, 3), new OreDictItemData(MT.Wood, U*8, MT.Bark, U), OD.logWood);
		
		if (IL.TF_Vial_FieryBlood.item() != null) IL.TF_Vial_FieryBlood.item().setContainerItem(Items.glass_bottle);
		if (IL.TF_Vial_FieryTears.item() != null) IL.TF_Vial_FieryTears.item().setContainerItem(Items.glass_bottle);
		
		IL.ERE_Umberstone                       .set(ST.make(MD.ERE, "umberstone"                           , 1, 0), OP.stone.dat(MT.Umber));
		IL.ERE_Umbercobble                      .set(ST.make(MD.ERE, "umberstone"                           , 1, 1), OP.stone.dat(MT.Umber));
		IL.ERE_Mud_Brick                        .set(ST.make(MD.ERE, "materials"                            , 1,23));
		IL.ERE_Spray_Repellant                  .set(ST.make(MD.ERE, "sprayCan"                             , 1, 0));
		IL.ERE_Herbicide                        .set(ST.make(MD.ERE, "planticide"                           , 1, 0));
		IL.ERE_Compost                          .set(ST.make(MD.ERE, "compost"                              , 1, 0), null, OD.itemFertilizer);
		IL.ERE_Gaean_Gem                        .set(ST.make(MD.ERE, "materials"                            , 1,39));
		IL.ERE_Gaean_Staff                      .set(ST.make(MD.ERE, "portalActivator"                      , 1, 0));
		IL.ERE_White_Planks                      .set(ST.make(MD.ERE, "planks"                                  , 1, 7));
		IL.ERE_White_Slab                       .set(ST.make(MD.ERE, "slabPlanksWhite"                      , 1, 0));
		IL.ERE_White_Stairs                     .set(ST.make(MD.ERE, "plankStairWhite"                      , 1, 0));
		
		IL.BTL_Swamp_Talisman                   .set(ST.make(MD.BTL, "swampTalisman"                        , 1, 0));
		IL.BTL_Tainted_Potion                   .set(ST.make(MD.BTL, "taintedPotion"                        , 1, 0));
		IL.BTL_Betweenstone                     .set(ST.make(MD.BTL, "betweenstone"                         , 1, 0), OP.stone.dat(MT.Betweenstone));
		IL.BTL_Pitstone                         .set(ST.make(MD.BTL, "pitstone"                             , 1, 0), OP.stone.dat(MT.Pitstone));
		IL.BTL_Bedrock                          .set(ST.make(MD.BTL, "bedrock"                              , 1, 0), OP.stone.dat(MT.Bedrock));
		IL.BTL_Chest                            .set(ST.make(MD.BTL, "weedwoodChest"                        , 1, 0), new OreDictItemData(MT.Weedwood, 8*U), OD.craftingChest);
		IL.BTL_Weedwood_Leaves                  .set(ST.make(MD.BTL, "weedwoodLeaves"                       , 1, 0), null, OP.treeLeaves);
		IL.BTL_Weedwood_Sapling                 .set(ST.make(MD.BTL, "saplingWeedwood"                      , 1, 0), null, OP.treeSapling);
		IL.BTL_Weedwood_Planks                  .set(ST.make(MD.BTL, "weedwoodPlanks"                       , 1, 0), new OreDictItemData(MT.Weedwood, U), OD.plankWeedwood);
		IL.BTL_Weedwood_Beam                    .set(ST.make(MD.BTL, "weedwood"                             , 1, 0), new OreDictItemData(MT.Weedwood, U*8), OD.beamWood);
		IL.BTL_Weedwood_Log                     .set(ST.make(MD.BTL, "weedwoodLog"                          , 1, 0), new OreDictItemData(MT.Weedwood, U*8, MT.Bark, U)); OM.reg(IL.BTL_Weedwood_Log.wild(1), OD.logWood);
		IL.BTL_Weedwood_Bark                    .set(ST.make(MD.BTL, "weedwoodBark"                         , 1, 0), new OreDictItemData(MT.Bark, U*9));
		IL.BTL_Weedwood_RottenBark              .set(ST.make(MD.BTL, "rottenWeedwoodBark"                   , 1, 0), new OreDictItemData(MT.Bark, U));
		IL.BTL_Portal_Bark                      .set(ST.make(MD.BTL, "portalBark"                           , 1, 0), new OreDictItemData(MT.Bark, U*9));
		IL.BTL_Bark                             .set(ST.make(MD.BTL, "groundStuff"                          , 1,16), OP.dust.dat(MT.Bark));
		IL.BTL_Resin                            .set(ST.make(MD.BTL, "sapBall"                              , 1, 0), null, OD.itemResin);
		IL.BTL_Rubber                           .set(ST.make(MD.BTL, "unknownGeneric"                       , 1,26), new OreDictItemData(MT.Rubber, U));
		IL.BTL_Skin                             .set(ST.make(MD.BTL, "unknownGeneric"                       , 1, 7), null, OD.itemSkin);
		IL.BTL_Tar                              .set(ST.make(MD.BTL, "unknownGeneric"                       , 1,39), null, OD.itemTar);
		
		IL.AETHER_Chest                         .set(ST.make(MD.AETHER, "skyrootChest"                      , 1, 0), new OreDictItemData(MT.Skyroot, 8*U), OD.craftingChest);
		IL.AETHER_Skyroot_Planks                .set(ST.make(MD.AETHER, "skyrootPlank"                      , 1, 0), new OreDictItemData(MT.Skyroot, U), OD.plankSkyroot);
		IL.AETHER_Skyroot_Log                   .set(ST.make(MD.AETHER, "aetherLog"                         , 1, 0), new OreDictItemData(MT.Skyroot, U*8, MT.Bark, U));
		IL.AETHER_Skyroot_Log_Gold              .set(ST.make(MD.AETHER, "aetherLog"                         , 1, 2), new OreDictItemData(MT.Skyroot, U*8, MT.Bark, U)); OM.reg(IL.AETHER_Skyroot_Log.wild(1), OD.logWood);
		IL.AETHER_Skyroot_Log_Small             .set(ST.make(MD.AETHER, "skyrootLogWall"                    , 1, 0), new OreDictItemData(MT.Skyroot, U*8, MT.Bark, U)); OM.reg(IL.AETHER_Skyroot_Log_Small.wild(1), OD.logWood);
		IL.AETHER_Torch_Ambrosium               .set(ST.make(MD.AETHER, "ambrosiumTorch"                    , 1, 0), new OreDictItemData(MT.Ambrosium, U8, MT.Skyroot, U16));
		IL.AETHER_Apple                         .set(ST.make(MD.AETHER, "whiteApple"                        , 1, 0), null, "cropAppleWhite");
		IL.AETHER_Tall_Grass                    .set(ST.make(MD.AETHER, "tallAetherGrass"                   , 1, 0), null, OD.itemGrassTall);
		IL.AETHER_Dirt                          .set(ST.make(MD.AETHER, "aetherDirt"                        , 1, 0));
		IL.AETHER_Grass                         .set(ST.make(MD.AETHER, "aetherGrass"                       , 1, 0));
		IL.AETHER_Grass_Enchanted               .set(ST.make(MD.AETHER, "enchantedAetherGrass"              , 1, 0));
		IL.AETHER_Grass_Enchanted_Vanilla       .set(ST.make(MD.AETHER, "enchantedGrass"                    , 1, 0));
		IL.AETHER_Skyroot_Sapling_Gold          .set(ST.make(MD.AETHER, "goldenOakSapling"                  , 1, 0), null, OP.treeSapling);
		IL.AETHER_Skyroot_Sapling_Green         .set(ST.make(MD.AETHER, "greenSkyrootSapling"               , 1, 0), null, OP.treeSapling);
		IL.AETHER_Skyroot_Sapling_Blue          .set(ST.make(MD.AETHER, "blueSkyrootSapling"                , 1, 0), null, OP.treeSapling);
		IL.AETHER_Skyroot_Sapling_Dark          .set(ST.make(MD.AETHER, "darkBlueSkyrootSapling"            , 1, 0), null, OP.treeSapling);
		IL.AETHER_Skyroot_Sapling_Purple        .set(ST.make(MD.AETHER, "purpleCrystalSapling"              , 1, 0), null, OP.treeSapling);
		IL.AETHER_Skyroot_Leaves_Gold           .set(ST.make(MD.AETHER, "goldenOakLeaves"                   , 1, 1), null, OP.treeLeaves);
		IL.AETHER_Skyroot_Leaves_Green          .set(ST.make(MD.AETHER, "greenSkyrootLeaves"                , 1, 1), null, OP.treeLeaves);
		IL.AETHER_Skyroot_Leaves_Blue           .set(ST.make(MD.AETHER, "blueSkyrootLeaves"                 , 1, 1), null, OP.treeLeaves);
		IL.AETHER_Skyroot_Leaves_Dark           .set(ST.make(MD.AETHER, "darkBlueSkyrootLeaves"             , 1, 1), null, OP.treeLeaves);
		IL.AETHER_Skyroot_Leaves_Purple         .set(ST.make(MD.AETHER, "purpleCrystalLeaves"               , 1, 1), null, OP.treeLeaves);
		IL.AETHER_Skyroot_Leaves_Apple          .set(ST.make(MD.AETHER, "purpleFruitLeaves"                 , 1, 1), null, OP.treeLeaves);
		
		if (IL.AETHER_Dirt.exists()) Textures.BlockIcons.DIRTS[1] = new IconContainerCopied(IL.AETHER_Dirt.block(), 0, SIDE_BOTTOM);
		
		IL.GrC_Honey_Jar                        .set(ST.make(MD.GrC_Bees, "grc.honeyJar"                    , 1, 0), null, OD.container1000honey);
		if (IL.GrC_Honey_Jar.item() != null) IL.GrC_Honey_Jar.item().setContainerItem(Items.flower_pot);
		
		IL.GrC_Honey_Bucket                     .set(ST.make(MD.GrC_Bees, "grc.BucketFluidHoney"            , 1, 0), null, OD.container1000honey);
		IL.GrC_Honey_Bottle                     .set(ST.make(MD.GrC_Bees, "grc.BottleFluidHoney"            , 1, 0), null, OD.container250honey);
		IL.GrC_Milk_Bucket                      .set(ST.make(MD.GrC_Milk, "grcmilk.BucketFluidMilk"         , 1, 0), null, OD.container1000milk);
		IL.GrC_Milk_Bottle                      .set(ST.make(MD.GrC_Milk, "grcmilk.BottleFluidMilk"         , 1, 0), null, OD.container250milk);
		IL.GrC_Cheese_Cheddar                   .set(ST.make(MD.GrC_Milk, "grcmilk.Cheese"                  , 1, 0), null, "foodCheeseCheddar");
		IL.GrC_Cheese_Gorgonzola                .set(ST.make(MD.GrC_Milk, "grcmilk.Cheese"                  , 1, 1), null, "foodCheeseGorgonzola");
		IL.GrC_Cheese_Swiss                     .set(ST.make(MD.GrC_Milk, "grcmilk.Cheese"                  , 1, 2), null, "foodCheeseSwiss");
		IL.GrC_Cheese_Appenzeller               .set(ST.make(MD.GrC_Milk, "grcmilk.Cheese"                  , 1, 3), null, "foodCheeseAppenzeller");
		IL.GrC_Cheese_Asiago                    .set(ST.make(MD.GrC_Milk, "grcmilk.Cheese"                  , 1, 4), null, "foodCheeseAsiago");
		IL.GrC_Cheese_Parmesan                  .set(ST.make(MD.GrC_Milk, "grcmilk.Cheese"                  , 1, 5), null, "foodCheeseParmesan");
		IL.GrC_Cheese_Monterey                  .set(ST.make(MD.GrC_Milk, "grcmilk.Cheese"                  , 1, 6), null, "foodCheeseMonterey");
		IL.GrC_Cheese_Ricotta                   .set(ST.make(MD.GrC_Milk, "grcmilk.Cheese"                  , 1, 7), null, "foodCheeseRicotta");
		IL.GrC_Starter_Culture                  .set(ST.make(MD.GrC_Milk, "grcmilk.StarterCulture"          , 1, 0));
		IL.GrC_Applecore                        .set(ST.make(MD.GrC_Apples, "grc.appleSeeds"                , 1, 0), null, OD.itemPlantRemains);
		IL.GrC_Bamboo                           .set(ST.make(MD.GrC_Bamboo, "grc.bamboo"                    , 1, 0), null, OD.bamboo);
		IL.GrC_Bamboo_Charcoal                  .set(ST.make(MD.GrC_Bamboo, "grc.bambooCoal"                , 1, 0), new OreDictItemData(MT.Charcoal, U2));
		IL.GrC_Paddy                            .set(ST.make(MD.GrC_Rice, "grc.paddyField"                  , 1, 0));
		IL.GrC_Ice_Cream                        .set(ST.make(MD.GrC_Milk, "grcmilk.IceCream"                , 1, 0), null, "foodIcecream");
		IL.GrC_Ice_Cream_Chocolate              .set(ST.make(MD.GrC_Milk, "grcmilk.IceCream"                , 1, 1), null, "foodChocolateicecream");
		IL.GrC_Ice_Cream_Grape                  .set(ST.make(MD.GrC_Milk, "grcmilk.IceCream"                , 1, 2), null, "foodGrapeicecream");
		IL.GrC_Ice_Cream_Apple                  .set(ST.make(MD.GrC_Milk, "grcmilk.IceCream"                , 1, 3), null, "foodAppleicecream");
		IL.GrC_Ice_Cream_Honey                  .set(ST.make(MD.GrC_Milk, "grcmilk.IceCream"                , 1, 4), null, "foodHoneyicecream");
		IL.GrC_Ice_Cream_Melon                  .set(ST.make(MD.GrC_Milk, "grcmilk.IceCream"                , 1, 5), null, "foodMelonicecream");
		
		IL.GrC_Grape_Purple                     .set(ST.make(MD.GrC_Grapes, "grc.grapes"                    , 1, 0), null, "cropGrapePurple");
		IL.GrC_Grape_Green                      .set(ST.make(MD.GrC_Grapes, "grc.grapes"                    , 1, 1), null, "cropGrapeGreen");
		IL.GrC_Grape_Red                        .set(ST.make(MD.GrC_Grapes, "grc.grapes"                    , 1, 2), null, "cropGrapeRed");
		
		IL.MoCr_Crab_Raw                        .set(ST.make(MD.MoCr, "crabraw"                             , 1, 0), new OreDictItemData(MT.FishRaw     , 3*U2), "foodCrabraw");
		IL.MoCr_Crab_Cooked                     .set(ST.make(MD.MoCr, "crabcooked"                          , 1, 0), new OreDictItemData(MT.FishCooked  , 3*U2), "foodCrabcooked");
		IL.MoCr_Turkey_Raw                      .set(ST.make(MD.MoCr, "turkeyraw"                           , 1, 0), new OreDictItemData(MT.MeatRaw     , U*3, MT.Bone, U4), "foodTurkeyraw");
		IL.MoCr_Turkey_Cooked                   .set(ST.make(MD.MoCr, "turkeycooked"                        , 1, 0), new OreDictItemData(MT.MeatCooked  , U*3, MT.Bone, U4), "foodTurkeycooked");
		IL.MoCr_Rat_Raw                         .set(ST.make(MD.MoCr, "ratraw"                              , 1, 0), new OreDictItemData(MT.MeatRaw     , U*1, MT.Bone, U9), "foodRatraw");
		IL.MoCr_Rat_Cooked                      .set(ST.make(MD.MoCr, "ratcooked"                           , 1, 0), new OreDictItemData(MT.MeatCooked  , U*1, MT.Bone, U9), "foodRatcooked");
		IL.MoCr_Ostrich_Raw                     .set(ST.make(MD.MoCr, "ostrichraw"                          , 1, 0), new OreDictItemData(MT.MeatRaw     , U*2, MT.Bone, U4), "foodOstrichraw");
		IL.MoCr_Ostrich_Cooked                  .set(ST.make(MD.MoCr, "ostrichcooked"                       , 1, 0), new OreDictItemData(MT.MeatCooked  , U*2, MT.Bone, U4), "foodOstrichcooked");
		IL.MoCr_Turtle_Raw                      .set(ST.make(MD.MoCr, "turtleraw"                           , 1, 0), new OreDictItemData(MT.MeatRaw     , U*2, MT.Bone, U9), "foodTurtleraw");
		
		IL.MaCu_Dye_White                       .set(ST.make(MD.MaCu, "materials"                           , 1,27), null, DYE_OREDICTS_MIXABLE[DYE_INDEX_White]);
		IL.MaCu_Dye_Blue                        .set(ST.make(MD.MaCu, "materials"                           , 1,28), null, DYE_OREDICTS_MIXABLE[DYE_INDEX_Blue]);
		IL.MaCu_Dye_Green                       .set(ST.make(MD.MaCu, "materials"                           , 1,29), null, DYE_OREDICTS_MIXABLE[DYE_INDEX_Green]);
		IL.MaCu_Dye_Yellow                      .set(ST.make(MD.MaCu, "materials"                           , 1,30), null, DYE_OREDICTS_MIXABLE[DYE_INDEX_Yellow]);
		IL.MaCu_Dye_Red                         .set(ST.make(MD.MaCu, "materials"                           , 1,31), null, DYE_OREDICTS_MIXABLE[DYE_INDEX_Red]);
		IL.MaCu_Dye_Brown                       .set(ST.make(MD.MaCu, "materials"                           , 1,32), null, DYE_OREDICTS_MIXABLE[DYE_INDEX_Brown]);
		IL.MaCu_Bait_Worm                       .set(ST.make(MD.MaCu, "bait"                                , 1, 0));
		IL.MaCu_Bait_Ant                        .set(ST.make(MD.MaCu, "bait"                                , 1, 1));
		IL.MaCu_Bait_Maggot                     .set(ST.make(MD.MaCu, "bait"                                , 1, 2));
		IL.MaCu_Bait_Grasshopper                .set(ST.make(MD.MaCu, "bait"                                , 1, 3));
		IL.MaCu_Bait_Bee                        .set(ST.make(MD.MaCu, "bait"                                , 1, 4));
		IL.MaCu_Polished_Planks                 .set(ST.make(MD.MaCu, "woods"                               , 1, 1), OP.plank.dat(MT.WoodPolished));
		IL.MaCu_Polished_Logs                   .set(ST.make(MD.MaCu, "woods"                               , 1, 2), new OreDictItemData(MT.WoodPolished, U*8, MT.Bark, U));
		
		IL.ENVM_Spoiled_Milk_Bucket             .set(ST.make(MD.ENVM, "spoiledMilk"                         , 1, 0));
		IL.ENVM_Rotten_Food                     .set(ST.make(MD.ENVM, "rottenFood"                          , 1, 0), null, "foodRotten");
		IL.ENVM_Bottle_Water_Cold               .set(ST.make(MD.ENVM, "coldWaterBottle"                     , 1, 0));
		IL.ENVM_Bottle_Water_Dirty              .set(ST.make(MD.ENVM, "badWaterBottle"                      , 1, 0));
		IL.ENVM_Bottle_Water_Salty              .set(ST.make(MD.ENVM, "saltWaterBottle"                     , 1, 0));
		
		IL.EtFu_Rabbit_Foot                     .set(ST.make(MD.EtFu, "rabbit_foot"                         , 1, 0));
		IL.EtFu_Beet_Seeds                      .set(ST.make(MD.EtFu, "beetroot_seeds"                      , 1, 0), null, "seedBeet");
		IL.EtFu_Dragon_Breath                   .set(ST.make(MD.EtFu, "dragon_breath"                       , 1, 0));
		IL.EtFu_Path                            .set(ST.make(MD.EtFu, "grass_path"                          , 1, 0));
		IL.EtFu_Dirt                            .set(ST.make(MD.EtFu, "coarse_dirt"                         , 1, 0));
		IL.EtFu_Gravel                          .set(ST.make(MD.EtFu, "old_gravel"                          , 1, 0));
		IL.EtFu_Granite                         .set(ST.make(MD.EtFu, "stone"                               , 1, 1));
		IL.EtFu_Granite_Smooth                  .set(ST.make(MD.EtFu, "stone"                               , 1, 2));
		IL.EtFu_Diorite                         .set(ST.make(MD.EtFu, "stone"                               , 1, 3));
		IL.EtFu_Diorite_Smooth                  .set(ST.make(MD.EtFu, "stone"                               , 1, 4));
		IL.EtFu_Andesite                        .set(ST.make(MD.EtFu, "stone"                               , 1, 5));
		IL.EtFu_Andesite_Smooth                 .set(ST.make(MD.EtFu, "stone"                               , 1, 6));
		
		IL.GaSu_Granite                         .set(ST.make(MD.GaSu, "18Stones"                            , 1, 1));
		IL.GaSu_Granite_Smooth                  .set(ST.make(MD.GaSu, "18Stones"                            , 1, 2));
		IL.GaSu_Diorite                         .set(ST.make(MD.GaSu, "18Stones"                            , 1, 3));
		IL.GaSu_Diorite_Smooth                  .set(ST.make(MD.GaSu, "18Stones"                            , 1, 4));
		IL.GaSu_Andesite                        .set(ST.make(MD.GaSu, "18Stones"                            , 1, 5));
		IL.GaSu_Andesite_Smooth                 .set(ST.make(MD.GaSu, "18Stones"                            , 1, 6));
		IL.GaSu_Basalt                          .set(ST.make(MD.GaSu, "basalt"                              , 1, 0));
		IL.GaSu_Basalt_Smooth                   .set(ST.make(MD.GaSu, "basalt"                              , 1, 1));
		IL.GaSu_Beet_Seeds                      .set(ST.make(MD.GaSu, "beetrootSeeds"                       , 1, 0), null, "seedBeet");
		
		IL.CHSL_Granite                         .set(ST.make(MD.CHSL, "granite"                             , 1, 0));
		IL.CHSL_Diorite                         .set(ST.make(MD.CHSL, "diorite"                             , 1, 0));
		IL.CHSL_Andesite                        .set(ST.make(MD.CHSL, "andesite"                            , 1, 0));
		IL.CHSL_Granite_Smooth                  .set(ST.make(MD.CHSL, "granite"                             , 1, 1));
		IL.CHSL_Diorite_Smooth                  .set(ST.make(MD.CHSL, "diorite"                             , 1, 1));
		IL.CHSL_Andesite_Smooth                 .set(ST.make(MD.CHSL, "andesite"                            , 1, 1));
		
		IL.BOTA_Livingrock                      .set(ST.make(MD.BOTA, "livingrock"                          , 1, 0));
		IL.BOTA_Granite                         .set(ST.make(MD.BOTA, "stone"                               , 1, 3));
		IL.BOTA_Diorite                         .set(ST.make(MD.BOTA, "stone"                               , 1, 2));
		IL.BOTA_Andesite                        .set(ST.make(MD.BOTA, "stone"                               , 1, 0));
		IL.BOTA_Granite_Smooth                  .set(ST.make(MD.BOTA, "stone"                               , 1, 7));
		IL.BOTA_Diorite_Smooth                  .set(ST.make(MD.BOTA, "stone"                               , 1, 6));
		IL.BOTA_Andesite_Smooth                 .set(ST.make(MD.BOTA, "stone"                               , 1, 4));
		IL.BOTA_Granite_Bricks                  .set(ST.make(MD.BOTA, "stone"                               , 1,11));
		IL.BOTA_Diorite_Bricks                  .set(ST.make(MD.BOTA, "stone"                               , 1,10));
		IL.BOTA_Andesite_Bricks                 .set(ST.make(MD.BOTA, "stone"                               , 1, 8));
		IL.BOTA_Granite_Chiseled                .set(ST.make(MD.BOTA, "stone"                               , 1,15));
		IL.BOTA_Diorite_Chiseled                .set(ST.make(MD.BOTA, "stone"                               , 1,14));
		IL.BOTA_Andesite_Chiseled               .set(ST.make(MD.BOTA, "stone"                               , 1,12));
		IL.BOTA_Prismarine                      .set(ST.make(MD.BOTA, "prismarine"                          , 1, 0));
		IL.BOTA_Prismarine_Bricks               .set(ST.make(MD.BOTA, "prismarine"                          , 1, 1));
		IL.BOTA_Prismarine_Dark                 .set(ST.make(MD.BOTA, "prismarine"                          , 1, 2));
		
		
		IL.EBXL_Cactus_Paste                    .set(ST.make(MD.EBXL, "extrabiomes.paste"                   , 1, 0));
		IL.EBXL_Dye_Black                       .set(ST.make(MD.EBXL, "extrabiomes.dye"                     , 1, 0), null, DYE_OREDICTS_MIXABLE[DYE_INDEX_Black]);
		IL.EBXL_Dye_Blue                        .set(ST.make(MD.EBXL, "extrabiomes.dye"                     , 1, 1), null, DYE_OREDICTS_MIXABLE[DYE_INDEX_Blue]);
		IL.EBXL_Dye_Brown                       .set(ST.make(MD.EBXL, "extrabiomes.dye"                     , 1, 2), null, DYE_OREDICTS_MIXABLE[DYE_INDEX_Brown]);
		IL.EBXL_Dye_White                       .set(ST.make(MD.EBXL, "extrabiomes.dye"                     , 1, 3), null, DYE_OREDICTS_MIXABLE[DYE_INDEX_White]);
		
		
		IL.EB_Dirt_Alfisol                      .set(ST.make(MD.EB, "enhancedbiomes.tile.dirtEB"            , 1, 0));
		IL.EB_Dirt_Andisol                      .set(ST.make(MD.EB, "enhancedbiomes.tile.dirtEB"            , 1, 1));
		IL.EB_Dirt_Gelisol                      .set(ST.make(MD.EB, "enhancedbiomes.tile.dirtEB"            , 1, 3));
		IL.EB_Dirt_Histosol                     .set(ST.make(MD.EB, "enhancedbiomes.tile.dirtEB"            , 1, 4));
		IL.EB_Dirt_Inceptisol                   .set(ST.make(MD.EB, "enhancedbiomes.tile.dirtEB"            , 1, 5));
		IL.EB_Dirt_Mollisol                     .set(ST.make(MD.EB, "enhancedbiomes.tile.dirtEB"            , 1, 6));
		IL.EB_Dirt_Oxisol                       .set(ST.make(MD.EB, "enhancedbiomes.tile.dirtEB"            , 1, 7));
		IL.EB_Grass_Alfisol                     .set(ST.make(MD.EB, "enhancedbiomes.tile.grassEB"           , 1, 0));
		IL.EB_Grass_Andisol                     .set(ST.make(MD.EB, "enhancedbiomes.tile.grassEB"           , 1, 1));
		IL.EB_Grass_Gelisol                     .set(ST.make(MD.EB, "enhancedbiomes.tile.grassEB"           , 1, 3));
		IL.EB_Grass_Histosol                    .set(ST.make(MD.EB, "enhancedbiomes.tile.grassEB"           , 1, 4));
		IL.EB_Grass_Inceptisol                  .set(ST.make(MD.EB, "enhancedbiomes.tile.grassEB"           , 1, 5));
		IL.EB_Grass_Mollisol                    .set(ST.make(MD.EB, "enhancedbiomes.tile.grassEB"           , 1, 6));
		IL.EB_Grass_Oxisol                      .set(ST.make(MD.EB, "enhancedbiomes.tile.grassEB"           , 1, 7));
		
		if (IL.EB_Dirt_Alfisol   .exists()) Textures.BlockIcons.DIRTS[ 5] = new IconContainerCopied(IL.EB_Dirt_Alfisol   .block(), 0, SIDE_BOTTOM);
		if (IL.EB_Dirt_Andisol   .exists()) Textures.BlockIcons.DIRTS[ 6] = new IconContainerCopied(IL.EB_Dirt_Andisol   .block(), 1, SIDE_BOTTOM);
		if (IL.EB_Dirt_Gelisol   .exists()) Textures.BlockIcons.DIRTS[ 7] = new IconContainerCopied(IL.EB_Dirt_Gelisol   .block(), 3, SIDE_BOTTOM);
		if (IL.EB_Dirt_Histosol  .exists()) Textures.BlockIcons.DIRTS[ 8] = new IconContainerCopied(IL.EB_Dirt_Histosol  .block(), 4, SIDE_BOTTOM);
		if (IL.EB_Dirt_Inceptisol.exists()) Textures.BlockIcons.DIRTS[ 9] = new IconContainerCopied(IL.EB_Dirt_Inceptisol.block(), 5, SIDE_BOTTOM);
		if (IL.EB_Dirt_Mollisol  .exists()) Textures.BlockIcons.DIRTS[10] = new IconContainerCopied(IL.EB_Dirt_Mollisol  .block(), 6, SIDE_BOTTOM);
		if (IL.EB_Dirt_Oxisol    .exists()) Textures.BlockIcons.DIRTS[11] = new IconContainerCopied(IL.EB_Dirt_Oxisol    .block(), 7, SIDE_BOTTOM);
		
		
		IL.BoP_Limestone                        .set(ST.make(MD.BoP, "rocks"                                , 1, 0), OP.stone.dat(MT.Limestone));
		IL.BoP_Limestone_Polished               .set(ST.make(MD.BoP, "rocks"                                , 1, 1), OP.stone.dat(MT.Limestone));
		IL.BoP_Siltstone                        .set(ST.make(MD.BoP, "rocks"                                , 1, 2), OP.stone.dat(MT.Siltstone));
		IL.BoP_Siltstone_Polished               .set(ST.make(MD.BoP, "rocks"                                , 1, 3), OP.stone.dat(MT.Siltstone));
		IL.BoP_Shale                            .set(ST.make(MD.BoP, "rocks"                                , 1, 4), OP.stone.dat(MT.Shale));
		IL.BoP_Shale_Polished                   .set(ST.make(MD.BoP, "rocks"                                , 1, 5), OP.stone.dat(MT.Shale));
		IL.BoP_Quicksand                        .set(ST.make(MD.BoP, "mud"                                  , 1, 1));
		IL.BoP_Mud                              .set(ST.make(MD.BoP, "mud"                                  , 1, 0));
		IL.BoP_Mud_Ball                         .set(ST.make(MD.BoP, "mudball"                              , 1, 0), null, OD.itemMud);
		IL.BoP_Mud_Brick                        .set(ST.make(MD.BoP, "misc"                                 , 1, 0));
		IL.BoP_Mud_Bricks                       .set(ST.make(MD.BoP, "mudBricks"                            , 1, 0));
		IL.BoP_Ashes                            .set(ST.make(MD.BoP, "misc"                                 , 1, 1), new OreDictItemData(MT.VolcanicAsh, U), DYE_OREDICTS_MIXABLE[DYE_INDEX_Gray]);
		IL.BoP_Ashes_Block                      .set(ST.make(MD.BoP, "ash"                                  , 1, 0), new OreDictItemData(MT.VolcanicAsh, U*4));
		IL.BoP_Ashstone                         .set(ST.make(MD.BoP, "ashStone"                             , 1, 0), new OreDictItemData(MT.VolcanicAsh, U));
		IL.BoP_Comb                             .set(ST.make(MD.BoP, "misc"                                 , 1, 2), null, OD.beeComb, "materialWaxcomb");
		IL.BoP_Flesh                            .set(ST.make(MD.BoP, "misc"                                 , 1, 3), new OreDictItemData(MT.MeatRaw, U));
		IL.BoP_Flesh_Block                      .set(ST.make(MD.BoP, "flesh"                                , 1, 0), new OreDictItemData(MT.MeatRaw, U*4));
		IL.BoP_Celestial                        .set(ST.make(MD.BoP, "misc"                                 , 1, 4));
		IL.BoP_Celestial_Block                  .set(ST.make(MD.BoP, "crystal"                              , 1, 0));
		IL.BoP_Dye_Blue                         .set(ST.make(MD.BoP, "misc"                                 , 1, 5), null, DYE_OREDICTS_MIXABLE[DYE_INDEX_Blue]);
		IL.BoP_Dye_Brown                        .set(ST.make(MD.BoP, "misc"                                 , 1, 6), null, DYE_OREDICTS_MIXABLE[DYE_INDEX_Brown]);
		IL.BoP_Dye_Green                        .set(ST.make(MD.BoP, "misc"                                 , 1, 7), null, DYE_OREDICTS_MIXABLE[DYE_INDEX_Green]);
		IL.BoP_Dye_White                        .set(ST.make(MD.BoP, "misc"                                 , 1, 8), null, DYE_OREDICTS_MIXABLE[DYE_INDEX_White]);
		IL.BoP_Dye_Black                        .set(ST.make(MD.BoP, "misc"                                 , 1, 9), null, DYE_OREDICTS_MIXABLE[DYE_INDEX_Black]);
		IL.BoP_GhastlySoul                      .set(ST.make(MD.BoP, "misc"                                 , 1,10));
		IL.BoP_PixieDust                        .set(ST.make(MD.BoP, "misc"                                 , 1,11));
		IL.BoP_Ichor                            .set(ST.make(MD.BoP, "misc"                                 , 1,12));
		IL.BoP_Pinecone                         .set(ST.make(MD.BoP, "misc"                                 , 1,13));
		IL.BoP_Bamboo                           .set(ST.make(MD.BoP, "bamboo"                               , 1, 0), null, OD.bamboo);
		IL.BoP_Hard_Ice                         .set(ST.make(MD.BoP, "hardIce"                              , 1, 0), new OreDictItemData(MT.Ice, U*2));
		IL.BoP_Crag_Rock                        .set(ST.make(MD.BoP, "cragRock"                             , 1, 0), new OreDictItemData(MT.Stone, U), OP.cobblestone);
		IL.BoP_Dirt_Dried                       .set(ST.make(MD.BoP, "driedDirt"                            , 1, 0));
		IL.BoP_Dirt_Hard                        .set(ST.make(MD.BoP, "hardDirt"                             , 1, 0));
		IL.BoP_Sand_Hard                        .set(ST.make(MD.BoP, "hardSand"                             , 1, 0));
		IL.BoP_Grass_Origin                     .set(ST.make(MD.BoP, "originGrass"                          , 1, 0));
		IL.BoP_Grass_Long                       .set(ST.make(MD.BoP, "longGrass"                            , 1, 0));
		IL.BoP_Grass_Netherrack                 .set(ST.make(MD.BoP, "overgrownNetherrack"                  , 1, 0), new OreDictItemData(MT.Netherrack, U));
		IL.BoP_Grass_Endstone                   .set(ST.make(MD.BoP, "bopGrass"                             , 1, 0), new OreDictItemData(MT.Endstone, U));
		IL.BoP_Grass_Smoldering                 .set(ST.make(MD.BoP, "bopGrass"                             , 1, 1));
		IL.BoP_Grass_Loamy                      .set(ST.make(MD.BoP, "newBopGrass"                          , 1, 0));
		IL.BoP_Grass_Sandy                      .set(ST.make(MD.BoP, "newBopGrass"                          , 1, 1));
		IL.BoP_Grass_Silty                      .set(ST.make(MD.BoP, "newBopGrass"                          , 1, 2));
		IL.BoP_Dirt_Loamy                       .set(ST.make(MD.BoP, "newBopDirt"                           , 1, 0));
		IL.BoP_Dirt_Sandy                       .set(ST.make(MD.BoP, "newBopDirt"                           , 1, 2));
		IL.BoP_Dirt_Silty                       .set(ST.make(MD.BoP, "newBopDirt"                           , 1, 4));
		IL.BoP_Coarse_Loamy                     .set(ST.make(MD.BoP, "newBopDirt"                           , 1, 1));
		IL.BoP_Coarse_Sandy                     .set(ST.make(MD.BoP, "newBopDirt"                           , 1, 3));
		IL.BoP_Coarse_Silty                     .set(ST.make(MD.BoP, "newBopDirt"                           , 1, 5));
		IL.BoP_Bone_Small                       .set(ST.make(MD.BoP, "bones"                                , 1, 0), new OreDictItemData(MT.Bone, U* 3));
		IL.BoP_Bone_Medium                      .set(ST.make(MD.BoP, "bones"                                , 1, 1), new OreDictItemData(MT.Bone, U* 6));
		IL.BoP_Bone_Large                       .set(ST.make(MD.BoP, "bones"                                , 1, 2), new OreDictItemData(MT.Bone, U*12));
		
		if (IL.BoP_Dirt_Loamy.exists()) Textures.BlockIcons.DIRTS[2] = new IconContainerCopied(IL.BoP_Dirt_Loamy.block(), 0, SIDE_BOTTOM);
		if (IL.BoP_Dirt_Sandy.exists()) Textures.BlockIcons.DIRTS[3] = new IconContainerCopied(IL.BoP_Dirt_Sandy.block(), 2, SIDE_BOTTOM);
		if (IL.BoP_Dirt_Silty.exists()) Textures.BlockIcons.DIRTS[4] = new IconContainerCopied(IL.BoP_Dirt_Silty.block(), 4, SIDE_BOTTOM);
		
		IL.BoP_Berry                            .set(ST.make(MD.BoP, "food"                                 , 1, 0), null, "cropBerry");
		IL.BoP_ShroomPowder                     .set(ST.make(MD.BoP, "food"                                 , 1, 1));
		IL.BoP_WildCarrots                      .set(ST.make(MD.BoP, "food"                                 , 1, 2), null, "cropWildcarrots");
		IL.BoP_Peach                            .set(ST.make(MD.BoP, "food"                                 , 1, 3), null, "cropPeach");
		IL.BoP_Persimmon                        .set(ST.make(MD.BoP, "food"                                 , 1, 8), null, "cropPersimmon");
		IL.BoP_HoneyComb                        .set(ST.make(MD.BoP, "food"                                 , 1, 9), null, OD.beeComb, "materialHoneycomb", "foodFilledhoneycomb");
		IL.BoP_Ambrosia                         .set(ST.make(MD.BoP, "food"                                 , 1,10), null, "foodAmbrosia");
		IL.BoP_Turnip                           .set(ST.make(MD.BoP, "food"                                 , 1,11), null, "cropTurnip");
		IL.BoP_Pear                             .set(ST.make(MD.BoP, "food"                                 , 1,12), null, "cropPear");
		IL.BoP_Turnip_Seeds                     .set(ST.make(MD.BoP, "turnipSeeds"                          , 1, 0), null, "seedTurnip");
		
		IL.BoP_Jar_Empty                        .set(ST.make(MD.BoP, "jarEmpty"                             , 1, 0), new OreDictItemData(MT.Glass, 7*U3));
		IL.BoP_Jar_Honey                        .set(ST.make(MD.BoP, "jarFilled"                            , 1, 0), new OreDictItemData(MT.Glass, 7*U3), "foodHoneydrop");
		IL.BoP_Jar_Poison                       .set(ST.make(MD.BoP, "jarFilled"                            , 1, 1), new OreDictItemData(MT.Glass, 7*U3));
		IL.BoP_Jar_Pixie                        .set(ST.make(MD.BoP, "jarFilled"                            , 1, 2), new OreDictItemData(MT.Glass, 7*U3));
		
		if (IL.BoP_Jar_Honey.item() != null && IL.BoP_Jar_Empty.item() != null) IL.BoP_Jar_Honey.item().setContainerItem(IL.BoP_Jar_Empty.item());
		
		
		IL.HiL_Ironwood                         .set(ST.make(MD.HiL, "tile.hl_ironwoodWood"                 , 1, 0), new OreDictItemData(ANY.Wood, U*8, MT.LiveRoot, U4), OD.logWood);
		
		
		IL.RoC_Comb_Slippery                    .set(ST.make(MD.RoC, "rotarycraft_item_modinterface"        , 1, 0), null, OD.beeComb);
		IL.RoC_Propolis_Slippery                .set(ST.make(MD.RoC, "rotarycraft_item_modinterface"        , 1, 1), null, OD.listAllpropolis);
		
		
		IL.JABBA_Dolly                          .set(ST.make(MD.JABBA, "mover"                              , 1, 0));
		IL.JABBA_Dolly_Diamond                  .set(ST.make(MD.JABBA, "moverDiamond"                       , 1, 0));
		
		
		IL.GC_Infinite_Oxygen                   .set(ST.make(MD.GC, "item.infiniteOxygen"                   , 1, 0)); ItemsGT.DEBUG_ITEMS.add(IL.GC_Infinite_Oxygen.wild(1)); ItemsGT.ILLEGAL_DROPS.add(IL.GC_Infinite_Oxygen.wild(1));
		IL.GC_Infinite_Battery                  .set(ST.make(MD.GC, "item.infiniteBattery"                  , 1, 0)); ItemsGT.DEBUG_ITEMS.add(IL.GC_Infinite_Battery.wild(1)); ItemsGT.ILLEGAL_DROPS.add(IL.GC_Infinite_Battery.wild(1));
		IL.GC_Torch_Glowstone                   .set(ST.make(MD.GC, "tile.glowstoneTorch"                   , 1, 0), new OreDictItemData(ANY.Glowstone, U4, ANY.Wood, U8));
		IL.GC_Canister                          .set(ST.make(MD.GC, "item.oilCanisterPartial"               , 1, 1001));
		IL.GC_OxyTank_1                         .set(ST.make(MD.GC, "item.oxygenTankLightFull"              , 1, 0));
		IL.GC_OxyTank_2                         .set(ST.make(MD.GC, "item.oxygenTankMedFull"                , 1, 0));
		IL.GC_OxyTank_3                         .set(ST.make(MD.GC, "item.oxygenTankHeavyFull"              , 1, 0));
		IL.GC_OxyTank_4                         .set(ST.make(MD.GC_GALAXYSPACE, "item.oxygentank_t4"        , 1, 0));
		IL.GC_OxyTank_5                         .set(ST.make(MD.GC_GALAXYSPACE, "item.oxygentank_t5"        , 1, 0));
		IL.GC_OxyTank_6                         .set(ST.make(MD.GC_GALAXYSPACE, "item.oxygentank_t6"        , 1, 0));
		IL.GC_OxyTank_Env                       .set(ST.make(MD.GC_GALAXYSPACE, "item.oxygentank_epp_t1"    , 1, 0));
		IL.GC_Schematic_1                       .set(ST.make(MD.GC, "item.schematic"                        , 1, 0));
		IL.GC_Schematic_2                       .set(ST.make(MD.GC_PLANETS, "item.schematic"                , 1, 0));
		IL.GC_Schematic_3                       .set(ST.make(MD.GC_GALAXYSPACE, "item.ItemSchematics"       , 1, 0));
		
		
		IL.TG_Ore_Cluster_1                     .set(ST.make(MD.TG, "oreCluster"                            , 1, 0)); ItemsGT.DEBUG_ITEMS.add(IL.TG_Ore_Cluster_1.wild(1)); ItemsGT.ILLEGAL_DROPS.add(IL.TG_Ore_Cluster_1.wild(1));
		IL.TG_Ore_Cluster_2                     .set(ST.make(MD.TG, "oreCluster2"                           , 1, 0)); ItemsGT.DEBUG_ITEMS.add(IL.TG_Ore_Cluster_2.wild(1)); ItemsGT.ILLEGAL_DROPS.add(IL.TG_Ore_Cluster_2.wild(1));
		IL.TG_Spawner_Bug                       .set(ST.make(MD.TG, "TGMonsterSpawner"                      , 1, 0));
		IL.TG_Spawner_Zombie                    .set(ST.make(MD.TG, "TGMonsterSpawner"                      , 1, 1));
		
		if (IL.TG_Ore_Cluster_1.block() != NB) IL.TG_Ore_Cluster_1.block().setHardness(1000).setResistance(6000000).setHarvestLevel(TOOL_pickaxe, 3);
		if (IL.TG_Ore_Cluster_2.block() != NB) IL.TG_Ore_Cluster_2.block().setHardness(1000).setResistance(6000000).setHarvestLevel(TOOL_pickaxe, 3);
		
		
		IL.MFR_Fertilizer                       .set(ST.make(MD.MFR, "fertilizer"                           , 1, 0), null, OD.itemFertilizer, DYE_OREDICTS_MIXABLE[DYE_INDEX_Brown]);
		IL.MFR_Log_Rubber                       .set(ST.make(MD.MFR, "rubberwood.log"                       , 1, 0), new OreDictItemData(MT.WoodRubber, U*8, MT.Bark, U), OD.logRubber);
		IL.MFR_Sapling_Rubber                   .set(ST.make(MD.MFR, "rubberwood.sapling"                   , 1, 0), null, OP.treeSapling);
		IL.MFR_Sapling_Rubber_Sacred            .set(ST.make(MD.MFR, "rubberwood.sapling"                   , 1, 1), null, OP.treeSapling);
		IL.MFR_Sapling_Rubber_Mega              .set(ST.make(MD.MFR, "rubberwood.sapling"                   , 1, 2), null, OP.treeSapling);
		IL.MFR_Sapling_Rubber_Sacred_Mega       .set(ST.make(MD.MFR, "rubberwood.sapling"                   , 1, 3), null, OP.treeSapling);
		IL.MFR_Leaves_Rubber                    .set(ST.make(MD.MFR, "rubberwood.leaves"                    , 1, 0), null, OP.treeLeaves);
		IL.MFR_Leaves_Rubber_Dry                .set(ST.make(MD.MFR, "rubberwood.leaves"                    , 1, 1), null, OP.treeLeaves);
		
		
		IL.AA_Fertilizer                        .set(ST.make(MD.AA, "itemFertilizer"                        , 1, 0), null, OD.itemFertilizer);
		IL.AA_Dye_Black                         .set(ST.make(MD.AA, "itemMisc"                              , 1,17), null, DYE_OREDICTS_MIXABLE[DYE_INDEX_Black]);
		
		
		IL.ICBM_Concrete                        .set(ST.make(MD.ICBM, "icbmCConcrete"                       , 1, 0));
		
		
		IL.FR_Planks_Fireproof                  .set(ST.make(MD.FR, "planksFireproof"                       , 1, 0));
		IL.FR_Planks                            .set(ST.make(MD.FR, "planks"                                , 1, 0));
		IL.FR_Slabs_Fireproof                   .set(ST.make(MD.FR, "slabsFireproof"                        , 1, 0));
		IL.FR_Slabs                             .set(ST.make(MD.FR, "slabs"                                 , 1, 0));
		IL.FR_Logs_Fireproof                    .set(ST.make(MD.FR, "logsFireproof"                         , 1, 0));
		IL.FR_Logs                              .set(ST.make(MD.FR, "logs"                                  , 1, 0));
		IL.FR_Phosphor                          .set(ST.make(MD.FR, "phosphor"                              , 1, 0), new OreDictItemData(MT.P, U));
		IL.FR_Royal_Jelly                       .set(ST.make(MD.FR, "royalJelly"                            , 1, 0));
		IL.FR_Propolis                          .set(ST.make(MD.FR, "propolis"                              , 1, 0), null, OD.listAllpropolis);
		IL.FR_Propolis_Sticky                   .set(ST.make(MD.FR, "propolis"                              , 1, 1), null, OD.listAllpropolis);
		IL.FR_Propolis_Pulsating                .set(ST.make(MD.FR, "propolis"                              , 1, 2), null, OD.listAllpropolis);
		IL.FR_Propolis_Silky                    .set(ST.make(MD.FR, "propolis"                              , 1, 3), null, OD.listAllpropolis);
		IL.FRMB_Propolis_Unstable               .set(ST.make(MD.FRMB, "propolis"                            , 1, 0), null, OD.listAllpropolis);
		IL.FRMB_Propolis_Breezey                .set(ST.make(MD.FRMB, "propolis"                            , 1, 1), null, OD.listAllpropolis);
		IL.FRMB_Propolis_Burning                .set(ST.make(MD.FRMB, "propolis"                            , 1, 2), null, OD.listAllpropolis);
		IL.FRMB_Propolis_Flowing                .set(ST.make(MD.FRMB, "propolis"                            , 1, 3), null, OD.listAllpropolis);
		IL.FRMB_Propolis_Stony                  .set(ST.make(MD.FRMB, "propolis"                            , 1, 4), null, OD.listAllpropolis);
		IL.FRMB_Propolis_Ordered                .set(ST.make(MD.FRMB, "propolis"                            , 1, 5), null, OD.listAllpropolis);
		IL.FRMB_Propolis_Chaotic                .set(ST.make(MD.FRMB, "propolis"                            , 1, 6), null, OD.listAllpropolis);
		if (MD.BINNIE_PATCHER.mLoaded) {
		IL.BINNIE_Propolis_Water                .set(ST.make(MD.BINNIE_BEE, "propolis"                      , 1, 0), null, OD.listAllpropolis);
		IL.BINNIE_Propolis_Oil                  .set(ST.make(MD.BINNIE_BEE, "propolis"                      , 1, 1), null, OD.listAllpropolis);
		IL.BINNIE_Propolis_Petroleum            .set(ST.make(MD.BINNIE_BEE, "propolis"                      , 1, 2), null, OD.listAllpropolis);
		IL.BINNIE_Propolis_Milk                 .set(ST.make(MD.BINNIE_BEE, "propolis"                      , 1, 3), null, OD.listAllpropolis);
		IL.BINNIE_Propolis_Fruit                .set(ST.make(MD.BINNIE_BEE, "propolis"                      , 1, 4), null, OD.listAllpropolis);
		IL.BINNIE_Propolis_Seed                 .set(ST.make(MD.BINNIE_BEE, "propolis"                      , 1, 5), null, OD.listAllpropolis);
		IL.BINNIE_Propolis_Alcohol              .set(ST.make(MD.BINNIE_BEE, "propolis"                      , 1, 6), null, OD.listAllpropolis);
		IL.BINNIE_Propolis_Creosote             .set(ST.make(MD.BINNIE_BEE, "propolis"                      , 1, 7), null, OD.listAllpropolis);
		IL.BINNIE_Propolis_Glacial              .set(ST.make(MD.BINNIE_BEE, "propolis"                      , 1, 8), null, OD.listAllpropolis);
		IL.BINNIE_Propolis_Peat                 .set(ST.make(MD.BINNIE_BEE, "propolis"                      , 1, 9), null, OD.listAllpropolis);
		} else {
		IL.BINNIE_Propolis_Water                .set(ST.make(MD.BINNIE_BEE, "propolis"                      , 1, 0), null, OD.listAllpropolis);
		IL.BINNIE_Propolis_Oil                  .set(ST.make(MD.BINNIE_BEE, "propolis"                      , 1, 1), null, OD.listAllpropolis);
		IL.BINNIE_Propolis_Petroleum            .set(ST.make(MD.BINNIE_BEE, "propolis"                      , 1, 2), null, OD.listAllpropolis);
		IL.BINNIE_Propolis_Creosote             .set(ST.make(MD.BINNIE_BEE, "propolis"                      , 1, 3), null, OD.listAllpropolis);
		IL.BINNIE_Propolis_Fruit                .set(ST.make(MD.BINNIE_BEE, "propolis"                      , 1, 4), null, OD.listAllpropolis);
		IL.BINNIE_Propolis_Seed                 .set(ST.make(MD.BINNIE_BEE, "propolis"                      , 1, 5), null, OD.listAllpropolis);
		IL.BINNIE_Propolis_Alcohol              .set(ST.make(MD.BINNIE_BEE, "propolis"                      , 1, 6), null, OD.listAllpropolis);
		IL.BINNIE_Propolis_Milk                 .set(ST.make(MD.BINNIE_BEE, "propolis"                      , 1, 7), null, OD.listAllpropolis);
		IL.BINNIE_Propolis_Glacial              .set(ST.make(MD.BINNIE_BEE, "propolis"                      , 1, 8), null, OD.listAllpropolis);
		IL.BINNIE_Propolis_Peat                 .set(ST.make(MD.BINNIE_BEE, "propolis"                      , 1, 9), null, OD.listAllpropolis);
		}
		IL.FR_Comb_Honey                        .set(ST.make(MD.FR, "beeCombs"                              , 1, 0), null, OD.beeComb, "materialHoneycomb", "foodFilledhoneycomb");
		IL.FR_Comb_Cocoa                        .set(ST.make(MD.FR, "beeCombs"                              , 1, 1), null, OD.beeComb);
		IL.FR_Comb_Simmering                    .set(ST.make(MD.FR, "beeCombs"                              , 1, 2), null, OD.beeComb);
		IL.FR_Comb_Stringy                      .set(ST.make(MD.FR, "beeCombs"                              , 1, 3), null, OD.beeComb);
		IL.FR_Comb_Frozen                       .set(ST.make(MD.FR, "beeCombs"                              , 1, 4), null, OD.beeComb);
		IL.FR_Comb_Dripping                     .set(ST.make(MD.FR, "beeCombs"                              , 1, 5), null, OD.beeComb);
		IL.FR_Comb_Silky                        .set(ST.make(MD.FR, "beeCombs"                              , 1, 6), null, OD.beeComb);
		IL.FR_Comb_Parched                      .set(ST.make(MD.FR, "beeCombs"                              , 1, 7), null, OD.beeComb);
		IL.FR_Comb_Mysterious                   .set(ST.make(MD.FR, "beeCombs"                              , 1, 8), null, OD.beeComb);
		IL.FR_Comb_Irradiated                   .set(ST.make(MD.FR, "beeCombs"                              , 1, 9), null, OD.beeComb);
		IL.FR_Comb_Powdery                      .set(ST.make(MD.FR, "beeCombs"                              , 1,10), null, OD.beeComb);
		IL.FR_Comb_Reddened                     .set(ST.make(MD.FR, "beeCombs"                              , 1,11), null, OD.beeComb);
		IL.FR_Comb_Darkened                     .set(ST.make(MD.FR, "beeCombs"                              , 1,12), null, OD.beeComb);
		IL.FR_Comb_Omega                        .set(ST.make(MD.FR, "beeCombs"                              , 1,13), null, OD.beeComb);
		IL.FR_Comb_Wheaten                      .set(ST.make(MD.FR, "beeCombs"                              , 1,14), null, OD.beeComb);
		IL.FR_Comb_Mossy                        .set(ST.make(MD.FR, "beeCombs"                              , 1,15), null, OD.beeComb);
		IL.FR_Comb_Mellow                       .set(ST.make(MD.FR, "beeCombs"                              , 1,16), null, OD.beeComb);
		if (MD.BINNIE_PATCHER.mLoaded) {
		IL.BINNIE_Comb_Barren                   .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1, 0), null, OD.beeComb);
		IL.BINNIE_Comb_Rotten                   .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1, 1), null, OD.beeComb);
		IL.BINNIE_Comb_Bone                     .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1, 2), null, OD.beeComb);
		IL.BINNIE_Comb_Oil                      .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1, 3), null, OD.beeComb);
		IL.BINNIE_Comb_Fossil                   .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1, 4), null, OD.beeComb);
		IL.BINNIE_Comb_Petroleum                .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1, 5), null, OD.beeComb);
		IL.BINNIE_Comb_Damp                     .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1, 6), null, OD.beeComb);
		IL.BINNIE_Comb_Milk                     .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1, 7), null, OD.beeComb);
		IL.BINNIE_Comb_Fruit                    .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1, 8), null, OD.beeComb);
		IL.BINNIE_Comb_Seed                     .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1, 9), null, OD.beeComb);
		IL.BINNIE_Comb_Alcohol                  .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1,10), null, OD.beeComb);
		IL.BINNIE_Comb_Rock                     .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1,11), null, OD.beeComb);
		IL.BINNIE_Comb_Energetic                .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1,12), null, OD.beeComb);
		IL.BINNIE_Comb_Amber                    .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1,13), null, OD.beeComb);
		IL.BINNIE_Comb_Static                   .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1,14), null, OD.beeComb);
		IL.BINNIE_Comb_Iron                     .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1,15), null, OD.beeComb);
		IL.BINNIE_Comb_Gold                     .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1,16), null, OD.beeComb);
		IL.BINNIE_Comb_Copper                   .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1,17), null, OD.beeComb);
		IL.BINNIE_Comb_Tin                      .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1,18), null, OD.beeComb);
		IL.BINNIE_Comb_Silver                   .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1,19), null, OD.beeComb);
		IL.BINNIE_Comb_Bronze                   .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1,20), null, OD.beeComb);
		IL.BINNIE_Comb_Uranium                  .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1,21), null, OD.beeComb);
		IL.BINNIE_Comb_Clay                     .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1,22), null, OD.beeComb);
		IL.BINNIE_Comb_Old                      .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1,23), null, OD.beeComb);
		IL.BINNIE_Comb_Fungal                   .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1,24), null, OD.beeComb);
		IL.BINNIE_Comb_Tar                      .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1,25), null, OD.beeComb);
		IL.BINNIE_Comb_Latex                    .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1,26), null, OD.beeComb);
		IL.BINNIE_Comb_Brimstone                .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1,27), null, OD.beeComb);
		IL.BINNIE_Comb_Venom                    .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1,28), null, OD.beeComb);
		IL.BINNIE_Comb_Mucous                   .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1,29), null, OD.beeComb);
		IL.BINNIE_Comb_Blaze                    .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1,30), null, OD.beeComb);
		IL.BINNIE_Comb_Coffee                   .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1,31), null, OD.beeComb);
		IL.BINNIE_Comb_Glacial                  .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1,32), null, OD.beeComb);
		IL.BINNIE_Comb_Mint                     .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1,33), null, OD.beeComb);
		IL.BINNIE_Comb_Citrus                   .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1,34), null, OD.beeComb);
		IL.BINNIE_Comb_Peat                     .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1,35), null, OD.beeComb);
		IL.BINNIE_Comb_Shadow                   .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1,36), null, OD.beeComb);
		IL.BINNIE_Comb_Lead                     .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1,37), null, OD.beeComb);
		IL.BINNIE_Comb_Brass                    .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1,38), null, OD.beeComb);
		IL.BINNIE_Comb_Electrum                 .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1,39), null, OD.beeComb);
		IL.BINNIE_Comb_Zinc                     .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1,40), null, OD.beeComb);
		IL.BINNIE_Comb_Titanium                 .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1,41), null, OD.beeComb);
		IL.BINNIE_Comb_Tungsten                 .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1,42), null, OD.beeComb);
		IL.BINNIE_Comb_Steel                    .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1,43), null, OD.beeComb);
		IL.BINNIE_Comb_Iridium                  .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1,44), null, OD.beeComb);
		IL.BINNIE_Comb_Platinum                 .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1,45), null, OD.beeComb);
		IL.BINNIE_Comb_Lapis                    .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1,46), null, OD.beeComb);
		IL.BINNIE_Comb_Sodalite                 .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1,47), null, OD.beeComb);
		IL.BINNIE_Comb_Pyrite                   .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1,48), null, OD.beeComb);
		IL.BINNIE_Comb_Bauxite                  .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1,49), null, OD.beeComb);
		IL.BINNIE_Comb_Cinnabar                 .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1,50), null, OD.beeComb);
		IL.BINNIE_Comb_Sphalerite               .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1,51), null, OD.beeComb);
		IL.BINNIE_Comb_Emerald                  .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1,52), null, OD.beeComb);
		IL.BINNIE_Comb_Ruby                     .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1,53), null, OD.beeComb);
		IL.BINNIE_Comb_Sapphire                 .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1,54), null, OD.beeComb);
		IL.BINNIE_Comb_Olivine                  .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1,55), null, OD.beeComb);
		IL.BINNIE_Comb_Diamond                  .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1,56), null, OD.beeComb);
		IL.BINNIE_Comb_Red                      .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1,57), null, OD.beeComb);
		IL.BINNIE_Comb_Yellow                   .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1,58), null, OD.beeComb);
		IL.BINNIE_Comb_Blue                     .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1,59), null, OD.beeComb);
		IL.BINNIE_Comb_Green                    .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1,60), null, OD.beeComb);
		IL.BINNIE_Comb_Black                    .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1,61), null, OD.beeComb);
		IL.BINNIE_Comb_White                    .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1,62), null, OD.beeComb);
		IL.BINNIE_Comb_Brown                    .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1,63), null, OD.beeComb);
		IL.BINNIE_Comb_Orange                   .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1,64), null, OD.beeComb);
		IL.BINNIE_Comb_Cyan                     .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1,65), null, OD.beeComb);
		IL.BINNIE_Comb_Purple                   .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1,66), null, OD.beeComb);
		IL.BINNIE_Comb_Gray                     .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1,67), null, OD.beeComb);
		IL.BINNIE_Comb_LightBlue                .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1,68), null, OD.beeComb);
		IL.BINNIE_Comb_Pink                     .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1,69), null, OD.beeComb);
		IL.BINNIE_Comb_Lime                     .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1,70), null, OD.beeComb);
		IL.BINNIE_Comb_Magenta                  .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1,71), null, OD.beeComb);
		IL.BINNIE_Comb_LightGray                .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1,72), null, OD.beeComb);
		IL.BINNIE_Comb_Nickel                   .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1,73), null, OD.beeComb);
		IL.BINNIE_Comb_Invar                    .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1,74), null, OD.beeComb);
		IL.BINNIE_Comb_Glowing                  .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1,75), null, OD.beeComb);
		IL.BINNIE_Comb_Unstable                 .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1,76), null, OD.beeComb);
		IL.BINNIE_Comb_Pulp                     .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1,77), null, OD.beeComb);
		IL.BINNIE_Comb_Mulch                    .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1,78), null, OD.beeComb);
		IL.BINNIE_Comb_Decomposed               .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1,79), null, OD.beeComb);
		IL.BINNIE_Comb_Dusty                    .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1,80), null, OD.beeComb);
		IL.BINNIE_Comb_Certus                   .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1,81), null, OD.beeComb);
		IL.BINNIE_Comb_Shimmering               .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1,82), null, OD.beeComb);
		IL.BINNIE_Comb_Yellorium                .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1,83), null, OD.beeComb);
		IL.BINNIE_Comb_Cyanite                  .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1,84), null, OD.beeComb);
		IL.BINNIE_Comb_Blutonium                .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1,85), null, OD.beeComb);
		} else {
		IL.BINNIE_Comb_Barren                   .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1, 0), null, OD.beeComb);
		IL.BINNIE_Comb_Rotten                   .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1, 1), null, OD.beeComb);
		IL.BINNIE_Comb_Bone                     .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1, 2), null, OD.beeComb);
		IL.BINNIE_Comb_Oil                      .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1, 3), null, OD.beeComb);
		IL.BINNIE_Comb_Fossil                   .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1, 4), null, OD.beeComb);
		IL.BINNIE_Comb_Petroleum                .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1, 5), null, OD.beeComb);
		IL.BINNIE_Comb_Damp                     .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1, 6), null, OD.beeComb);
		IL.BINNIE_Comb_Milk                     .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1, 7), null, OD.beeComb);
		IL.BINNIE_Comb_Fruit                    .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1, 8), null, OD.beeComb);
		IL.BINNIE_Comb_Seed                     .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1, 9), null, OD.beeComb);
		IL.BINNIE_Comb_Alcohol                  .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1,10), null, OD.beeComb);
		IL.BINNIE_Comb_Rock                     .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1,11), null, OD.beeComb);
		IL.BINNIE_Comb_Energetic                .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1,12), null, OD.beeComb);
		IL.BINNIE_Comb_Amber                    .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1,13), null, OD.beeComb);
		IL.BINNIE_Comb_Static                   .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1,14), null, OD.beeComb);
		IL.BINNIE_Comb_Iron                     .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1,15), null, OD.beeComb);
		IL.BINNIE_Comb_Gold                     .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1,16), null, OD.beeComb);
		IL.BINNIE_Comb_Copper                   .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1,17), null, OD.beeComb);
		IL.BINNIE_Comb_Tin                      .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1,18), null, OD.beeComb);
		IL.BINNIE_Comb_Silver                   .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1,19), null, OD.beeComb);
		IL.BINNIE_Comb_Uranium                  .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1,20), null, OD.beeComb);
		IL.BINNIE_Comb_Clay                     .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1,21), null, OD.beeComb);
		IL.BINNIE_Comb_Old                      .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1,22), null, OD.beeComb);
		IL.BINNIE_Comb_Fungal                   .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1,23), null, OD.beeComb);
		IL.BINNIE_Comb_Tar                      .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1,24), null, OD.beeComb);
		IL.BINNIE_Comb_Latex                    .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1,25), null, OD.beeComb);
		IL.BINNIE_Comb_Brimstone                .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1,26), null, OD.beeComb);
		IL.BINNIE_Comb_Venom                    .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1,27), null, OD.beeComb);
		IL.BINNIE_Comb_Mucous                   .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1,28), null, OD.beeComb);
		IL.BINNIE_Comb_Blaze                    .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1,29), null, OD.beeComb);
		IL.BINNIE_Comb_Coffee                   .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1,30), null, OD.beeComb);
		IL.BINNIE_Comb_Glacial                  .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1,31), null, OD.beeComb);
		IL.BINNIE_Comb_Shadow                   .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1,32), null, OD.beeComb);
		IL.BINNIE_Comb_Lead                     .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1,33), null, OD.beeComb);
		IL.BINNIE_Comb_Brass                    .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1,34), null, OD.beeComb);
		IL.BINNIE_Comb_Titanium                 .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1,35), null, OD.beeComb);
		IL.BINNIE_Comb_Tungsten                 .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1,36), null, OD.beeComb);
		IL.BINNIE_Comb_Platinum                 .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1,37), null, OD.beeComb);
		IL.BINNIE_Comb_Lapis                    .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1,38), null, OD.beeComb);
		IL.BINNIE_Comb_Emerald                  .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1,39), null, OD.beeComb);
		IL.BINNIE_Comb_Ruby                     .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1,40), null, OD.beeComb);
		IL.BINNIE_Comb_Sapphire                 .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1,41), null, OD.beeComb);
		IL.BINNIE_Comb_Diamond                  .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1,42), null, OD.beeComb);
		IL.BINNIE_Comb_Red                      .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1,43), null, OD.beeComb);
		IL.BINNIE_Comb_Yellow                   .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1,44), null, OD.beeComb);
		IL.BINNIE_Comb_Blue                     .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1,45), null, OD.beeComb);
		IL.BINNIE_Comb_Green                    .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1,46), null, OD.beeComb);
		IL.BINNIE_Comb_Black                    .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1,47), null, OD.beeComb);
		IL.BINNIE_Comb_White                    .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1,48), null, OD.beeComb);
		IL.BINNIE_Comb_Brown                    .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1,49), null, OD.beeComb);
		IL.BINNIE_Comb_Orange                   .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1,50), null, OD.beeComb);
		IL.BINNIE_Comb_Cyan                     .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1,51), null, OD.beeComb);
		IL.BINNIE_Comb_Purple                   .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1,52), null, OD.beeComb);
		IL.BINNIE_Comb_Gray                     .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1,53), null, OD.beeComb);
		IL.BINNIE_Comb_LightBlue                .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1,54), null, OD.beeComb);
		IL.BINNIE_Comb_Pink                     .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1,55), null, OD.beeComb);
		IL.BINNIE_Comb_Lime                     .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1,56), null, OD.beeComb);
		IL.BINNIE_Comb_Magenta                  .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1,57), null, OD.beeComb);
		IL.BINNIE_Comb_LightGray                .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1,58), null, OD.beeComb);
		IL.BINNIE_Comb_Nickel                   .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1,59), null, OD.beeComb);
		IL.BINNIE_Comb_Glowing                  .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1,60), null, OD.beeComb);
		IL.BINNIE_Comb_Unstable                 .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1,61), null, OD.beeComb);
		IL.BINNIE_Comb_Decomposed               .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1,62), null, OD.beeComb);
		IL.BINNIE_Comb_Dusty                    .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1,63), null, OD.beeComb);
		IL.BINNIE_Comb_Certus                   .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1,64), null, OD.beeComb);
		IL.BINNIE_Comb_Shimmering               .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1,65), null, OD.beeComb);
		IL.BINNIE_Comb_Yellorium                .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1,66), null, OD.beeComb);
		IL.BINNIE_Comb_Cyanite                  .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1,67), null, OD.beeComb);
		IL.BINNIE_Comb_Blutonium                .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1,68), null, OD.beeComb);
		IL.BINNIE_Comb_Bronze                   .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1,69), null, OD.beeComb);
		IL.BINNIE_Comb_Mint                     .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1,70), null, OD.beeComb);
		IL.BINNIE_Comb_Citrus                   .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1,71), null, OD.beeComb);
		IL.BINNIE_Comb_Peat                     .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1,72), null, OD.beeComb);
		IL.BINNIE_Comb_Electrum                 .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1,73), null, OD.beeComb);
		IL.BINNIE_Comb_Zinc                     .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1,74), null, OD.beeComb);
		IL.BINNIE_Comb_Steel                    .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1,75), null, OD.beeComb);
		IL.BINNIE_Comb_Iridium                  .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1,76), null, OD.beeComb);
		IL.BINNIE_Comb_Sodalite                 .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1,77), null, OD.beeComb);
		IL.BINNIE_Comb_Pyrite                   .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1,78), null, OD.beeComb);
		IL.BINNIE_Comb_Bauxite                  .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1,79), null, OD.beeComb);
		IL.BINNIE_Comb_Cinnabar                 .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1,80), null, OD.beeComb);
		IL.BINNIE_Comb_Sphalerite               .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1,81), null, OD.beeComb);
		IL.BINNIE_Comb_Olivine                  .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1,82), null, OD.beeComb);
		IL.BINNIE_Comb_Invar                    .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1,83), null, OD.beeComb);
		IL.BINNIE_Comb_Pulp                     .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1,84), null, OD.beeComb);
		IL.BINNIE_Comb_Mulch                    .set(ST.make(MD.BINNIE_BEE, "honeyComb"                     , 1,85), null, OD.beeComb);
		}
		IL.FR_Pollen_Cluster                    .set(ST.make(MD.FR, "pollen"                                , 1, 0));
		IL.FR_Pollen_Cluster_Crystalline        .set(ST.make(MD.FR, "pollen"                                , 1, 1));
		IL.FR_Mulch                             .set(ST.make(MD.FR, "mulch"                                 , 1, 0));
		IL.FR_Fertilizer                        .set(ST.make(MD.FR, "fertilizerCompound"                    , 1, 0), null, OD.itemFertilizer);
		IL.FR_Compost                           .set(ST.make(MD.FR, "fertilizerBio"                         , 1, 0));
		IL.FR_Pulsating_Dust                    .set(ST.make(MD.FR, "craftingMaterial"                      , 1, 0), new OreDictItemData(MT.EnderPearl, U));
		IL.FR_Pulsating_Mesh                    .set(ST.make(MD.FR, "craftingMaterial"                      , 1, 1));
		IL.FR_Silk                              .set(ST.make(MD.FR, "craftingMaterial"                      , 1, 2));
		IL.FR_Silk_Woven                        .set(ST.make(MD.FR, "craftingMaterial"                      , 1, 3));
		IL.FR_Dissipation_Capsule               .set(ST.make(MD.FR, "craftingMaterial"                      , 1, 4));
		IL.FR_Ice_Shard                         .set(ST.make(MD.FR, "craftingMaterial"                      , 1, 5), new OreDictItemData(MT.Ice, U));
		IL.FR_Iodine_Capsule                    .set(ST.make(MD.FR, "iodineCapsule"                         , 1, 0));
		IL.FR_HoneyPot                          .set(ST.make(MD.FR, "honeyPot"                              , 1, 0));
		IL.FR_Ambrosia                          .set(ST.make(MD.FR, "ambrosia"                              , 1, 0), null, "foodAmbrosia");
		IL.FR_TinCapsule                        .set(ST.make(MD.FR, "canEmpty"                              , 1, 0), new OreDictItemData(MT.Sn, 3*U12));
		IL.FR_WaxCapsule                        .set(ST.make(MD.FR, "waxCapsule"                            , 1, 0), new OreDictItemData(MT.WaxBee, 3*U4));
		IL.FR_RefractoryCapsule                 .set(ST.make(MD.FR, "refractoryEmpty"                       , 1, 0), new OreDictItemData(MT.WaxRefractory, 3*U4));
		IL.FR_MagicCapsule                      .set(ST.make(MD.FRMB, "capsule.magic"                       , 1, 0), new OreDictItemData(MT.WaxMagic, 3*U4));
		IL.FR_Honey_Bucket                      .set(ST.make(MD.FR, "bucketHoney"                           , 1, 0), null, OD.container1000honey, "bucketHoney");
		IL.FR_Honey_Can                         .set(ST.make(MD.FR, "canHoney"                              , 1, 0), null, OD.container1000honey);
		IL.FR_Honey_Capsule                     .set(ST.make(MD.FR, "waxCapsuleHoney"                       , 1, 0), null, OD.container1000honey);
		IL.FR_Honey_RefractoryCapsule           .set(ST.make(MD.FR, "refractoryHoney"                       , 1, 0), null, OD.container1000honey);
		IL.FR_Water_Can                         .set(ST.make(MD.FR, "canWater"                              , 1, 0), null, OD.container1000water);
		IL.FR_Water_Capsule                     .set(ST.make(MD.FR, "waxCapsuleWater"                       , 1, 0), null, OD.container1000water);
		IL.FR_Water_RefractoryCapsule           .set(ST.make(MD.FR, "refractoryWater"                       , 1, 0), null, OD.container1000water);
		IL.FR_Lava_RefractoryCapsule            .set(ST.make(MD.FR, "refractoryLava"                        , 1, 0), null, OD.container1000lava);
		IL.FR_Candle                            .set(ST.make(MD.FR, "candle"                                , 1, 0));
		IL.FR_Bee_Drone                         .set(ST.make(MD.FR, "beeDroneGE"                            , 1, 0));
		IL.FR_Bee_Princess                      .set(ST.make(MD.FR, "beePrincessGE"                         , 1, 0));
		IL.FR_Bee_Queen                         .set(ST.make(MD.FR, "beeQueenGE"                            , 1, 0));
		IL.FR_Tree_Sapling                      .set(ST.make(MD.FR, "sapling"                               , 1, 0, ST.make(MD.FR, "saplingGE", 1)));
		IL.FR_Butterfly                         .set(ST.make(MD.FR, "butterflyGE"                           , 1, 0));
		IL.FR_Larvae                            .set(ST.make(MD.FR, "beeLarvaeGE"                           , 1, 0));
		IL.FR_Serum                             .set(ST.make(MD.FR, "serumGE"                               , 1, 0));
		IL.FR_Caterpillar                       .set(ST.make(MD.FR, "caterpillarGE"                         , 1, 0));
		IL.FR_PollenFertile                     .set(ST.make(MD.FR, "pollenFertile"                         , 1, 0));
		IL.FR_Stick                             .set(ST.make(MD.FR, "oakStick"                              , 1, 0));
		IL.FR_Scoop                             .set(ST.make(MD.FR, "scoop"                                 , 1, 0));
		IL.FR_Casing_Impregnated                .set(ST.make(MD.FR, "impregnatedCasing"                     , 1, 0), new OreDictItemData(ANY.Wood           , U *64));
		IL.FR_Casing_Sturdy                     .set(ST.make(MD.FR, "sturdyMachine"                         , 1, 0), new OreDictItemData(MT.Bronze          , U * 8));
		IL.FR_Casing_Hardened                   .set(ST.make(MD.FR, "hardenedMachine"                       , 1, 0), new OreDictItemData(MT.Bronze          , U * 8, MT.Diamond, U * 4));
		IL.FR_Chipset_Tin                       .set(ST.make(MD.FR, "chipsets"                              , 1, 0), new OreDictItemData(MT.Sn              , U * 1, MT.Redstone, U * 6));
		IL.FR_Chipset_Bronze                    .set(ST.make(MD.FR, "chipsets"                              , 1, 1), new OreDictItemData(MT.Bronze          , U * 3, MT.Redstone, U * 6));
		IL.FR_Chipset_Iron                      .set(ST.make(MD.FR, "chipsets"                              , 1, 2), new OreDictItemData(ANY.Fe             , U * 3, MT.Redstone, U * 6));
		IL.FR_Chipset_Gold                      .set(ST.make(MD.FR, "chipsets"                              , 1, 3), new OreDictItemData(MT.Au              , U * 3, MT.Redstone, U * 6));
		IL.FR_ElectronTube_Copper               .set(ST.make(MD.FR, "thermionicTubes"                       , 1, 0), new OreDictItemData(MT.Cu              , 5*U4, MT.Redstone, U2, MT.Glass, U8));
		IL.FR_ElectronTube_Tin                  .set(ST.make(MD.FR, "thermionicTubes"                       , 1, 1), new OreDictItemData(MT.Sn              , 5*U4, MT.Redstone, U2, MT.Glass, U8));
		IL.FR_ElectronTube_Bronze               .set(ST.make(MD.FR, "thermionicTubes"                       , 1, 2), new OreDictItemData(MT.Bronze          , 5*U4, MT.Redstone, U2, MT.Glass, U8));
		IL.FR_ElectronTube_Iron                 .set(ST.make(MD.FR, "thermionicTubes"                       , 1, 3), new OreDictItemData(ANY.Fe             , 5*U4, MT.Redstone, U2, MT.Glass, U8));
		IL.FR_ElectronTube_Gold                 .set(ST.make(MD.FR, "thermionicTubes"                       , 1, 4), new OreDictItemData(MT.Au              , 5*U4, MT.Redstone, U2, MT.Glass, U8));
		IL.FR_ElectronTube_Diamond              .set(ST.make(MD.FR, "thermionicTubes"                       , 1, 5), new OreDictItemData(MT.Diamond         , 5*U4, MT.Redstone, U2, MT.Glass, U8));
		IL.FR_ElectronTube_Obsidian             .set(ST.make(MD.FR, "thermionicTubes"                       , 1, 6), new OreDictItemData(MT.Obsidian        , 5*U4, MT.Redstone, U2, MT.Glass, U8));
		IL.FR_ElectronTube_Blaze                .set(ST.make(MD.FR, "thermionicTubes"                       , 1, 7), new OreDictItemData(MT.Blaze           , 5*U4, MT.Redstone, U2, MT.Glass, U8));
		IL.FR_ElectronTube_Rubber               .set(ST.make(MD.FR, "thermionicTubes"                       , 1, 8), new OreDictItemData(MT.Rubber          , 5*U4, MT.Redstone, U2, MT.Glass, U8));
		IL.FR_ElectronTube_Emerald              .set(ST.make(MD.FR, "thermionicTubes"                       , 1, 9), new OreDictItemData(ANY.Emerald        , 5*U4, MT.Redstone, U2, MT.Glass, U8));
		IL.FR_ElectronTube_Apatite              .set(ST.make(MD.FR, "thermionicTubes"                       , 1,10), new OreDictItemData(MT.Apatite         , 5*U4, MT.Redstone, U2, MT.Glass, U8));
		IL.FR_ElectronTube_Lapis                .set(ST.make(MD.FR, "thermionicTubes"                       , 1,11), new OreDictItemData(MT.Lapis           , 5*U4, MT.Redstone, U2, MT.Glass, U8));
		IL.FR_ElectronTube_Ender                .set(ST.make(MD.FR, "thermionicTubes"                       , 1,12), new OreDictItemData(MT.Endstone        , 5*U4, MT.EnderEye, U2, MT.Glass, U8));
		IL.BINNIE_Dye_Red                       .set(ST.make(MD.BINNIE_BEE, "misc"                          , 1,19), null, DYE_OREDICTS_MIXABLE[DYE_INDEX_Red]);
		IL.BINNIE_Dye_Yellow                    .set(ST.make(MD.BINNIE_BEE, "misc"                          , 1,20), null, DYE_OREDICTS_MIXABLE[DYE_INDEX_Yellow]);
		IL.BINNIE_Dye_Blue                      .set(ST.make(MD.BINNIE_BEE, "misc"                          , 1,21), null, DYE_OREDICTS_MIXABLE[DYE_INDEX_Blue]);
		IL.BINNIE_Dye_Green                     .set(ST.make(MD.BINNIE_BEE, "misc"                          , 1,22), null, DYE_OREDICTS_MIXABLE[DYE_INDEX_Green]);
		IL.BINNIE_Dye_White                     .set(ST.make(MD.BINNIE_BEE, "misc"                          , 1,23), null, DYE_OREDICTS_MIXABLE[DYE_INDEX_White]);
		IL.BINNIE_Dye_Black                     .set(ST.make(MD.BINNIE_BEE, "misc"                          , 1,24), null, DYE_OREDICTS_MIXABLE[DYE_INDEX_Black]);
		IL.BINNIE_Dye_Brown                     .set(ST.make(MD.BINNIE_BEE, "misc"                          , 1,25), null, DYE_OREDICTS_MIXABLE[DYE_INDEX_Brown]);
		
		ST.item(MD.BINNIE, "containerGlass", Items.potionitem).setContainerItem(Items.glass_bottle);
		
		IL.Cell_Empty                           .set(ST.mkic("cell"                                         , 1   ), OP.cell.dat(MT.Empty));
		IL.Cell_Water                           .set(ST.mkic("waterCell"                                    , 1   ), OP.cell.dat(MT.Water), OD.container1000water);
		IL.Cell_Lava                            .set(ST.mkic("lavaCell"                                     , 1   ), OP.cell.dat(MT.Lava), OD.container1000lava);
		IL.Cell_Air                             .set(ST.mkic("airCell"                                      , 1   ), OP.cell.dat(MT.Air));
		OP.cell.mContainerItem =                     ST.mkic("cell"                                         , 1   , OreDictManager.INSTANCE.getFirstOre("cellEmpty", 1));
		
		if (MD.IC2C.mLoaded) {
		IL.IC2_Iridium_Shard                    .set(NI);
		IL.IC2_Energium_Dust                    .set(NI);
		IL.IC2_Fuel_Rod_Empty                   .set(NI);
		IL.IC2_Biochaff                         .set(ST.mkic("plantBall"                                    , 1   ));
		IL.IC2_ShaftIron                        .set(NI);
		IL.IC2_ShaftSteel                       .set(NI);
		IL.IC2_ForgeHammer                      .set(NI);
		IL.IC2_Debug                            .set(NI);
		IL.IC2_AdvBattery                       .set(NI);
		IL.Cell_Universal_Fluid                 .set(NI);
		IL.Cell_UUM                             .set(NI);
		IL.Cell_CFoam                           .set(NI);
		} else {
		IL.IC2_Iridium_Shard                    .set(ST.mkic("iridiumShard"                                 , 1   ), new OreDictItemData(MT.Ir, U9));
		IL.IC2_Energium_Dust                    .set(ST.mkic("energiumDust"                                 , 1   ));
		IL.IC2_Fuel_Rod_Empty                   .set(ST.mkic("fuelRod"                                      , 1   ), new OreDictItemData(MD.GT.mLoaded?MT.Zr:ANY.Fe, U));
		IL.IC2_Biochaff                         .set(ST.mkic("biochaff"                                     , 1   ));
		IL.IC2_ShaftIron                        .set(ST.mkic("ironshaft"                                    , 1   ), new OreDictItemData(ANY.Fe, U*9));
		IL.IC2_ShaftSteel                       .set(ST.mkic("steelshaft"                                   , 1   ), new OreDictItemData(ANY.Steel, U*9));
		IL.IC2_ForgeHammer                      .set(ST.mkic("ForgeHammer"                                  , 1   ));
		IL.IC2_Debug                            .set(ST.mkic("debug"                                        , 1   )); ItemsGT.DEBUG_ITEMS.add(IL.IC2_Debug.wild(1)); ItemsGT.ILLEGAL_DROPS.add(IL.IC2_Debug.wild(1));
		IL.IC2_AdvBattery                       .set(ST.mkic("advBattery"                                   , 1   ));
		IL.Cell_Universal_Fluid                 .set(ST.mkic("FluidCell"                                    , 1   ), new OreDictItemData(MT.Sn, U*2, OM.stack(MT.Glass, 3*U8)));
		IL.Cell_UUM                             .set(ST.mkic("uuMatterCell"                                 , 1   ), OP.cell.dat(MT.UUMatter));
		IL.Cell_CFoam                           .set(ST.mkic("CFCell"                                       , 1   ), OP.cell.dat(MT.ConstructionFoam));
		}
		
		IL.IC2_Iridium_Ore                      .set(ST.mkic("iridiumOre"                                   , 1   ), new OreDictItemData(MT.Ir, U));
		IL.IC2_Scaffold                         .set(ST.mkic("scaffold"                                     , 1   ), new OreDictItemData(ANY.Wood, 9*U8));
		IL.IC2_Scaffold_Iron                    .set(ST.mkic("ironScaffold"                                 , 1   ), new OreDictItemData(ANY.Fe, 15*U32));
		IL.IC2_Foam                             .set(ST.mkic("constructionFoam"                             , 1   ));
		IL.IC2_Foam_Reinforced                  .set(ST.mkic("constructionreinforcedFoam"                   , 1   ));
		IL.IC2_Wall                             .set(ST.mkic("constructionFoamWall"                         , 1   ));
		IL.IC2_Wall_Reinforced                  .set(ST.mkic("reinforcedStone"                              , 1   ));
		IL.IC2_Glass_Reinforced                 .set(ST.mkic("reinforcedGlass"                              , 1   ));
		IL.IC2_Spray_WeedEx                     .set(ST.mkic("weedEx"                                       , 1   ), new OreDictItemData(MT.Sn, U, MT.Redstone, U));
		IL.IC2_Mixed_Metal_Ingot                .set(ST.mkic("mixedMetalIngot"                              , 1   ));
		IL.IC2_Fertilizer                       .set(ST.mkic("fertilizer"                                   , 1   ), null, OD.itemFertilizer);
		IL.IC2_Resin                            .set(ST.mkic("resin"                                        , 1   ), null, OD.itemResin);
		IL.IC2_Log_Rubber                       .set(ST.mkic("rubberWood"                                   , 1   ), new OreDictItemData(MT.WoodRubber, U*8, MT.Bark, U), OD.logRubber);
		IL.IC2_Leaves_Rubber                    .set(ST.mkic("rubberLeaves"                                 , 1   ));
		IL.IC2_Sapling_Rubber                   .set(ST.mkic("rubberSapling"                                , 1   ));
		IL.IC2_Plantball                        .set(ST.mkic("plantBall"                                    , 1   ));
		IL.IC2_Crop_Seeds                       .set(ST.mkic("cropSeed"                                     , 1   ), null, "seedCrop");
		IL.IC2_Grin_Powder                      .set(ST.mkic("grinPowder"                                   , 1   ));
		IL.IC2_Scrap                            .set(ST.mkic("scrap"                                        , 1   ));
		IL.IC2_Scrapbox                         .set(ST.mkic("scrapBox"                                     , 1   ));
		IL.IC2_Food_Can_Empty                   .set(ST.mkic("tinCan"                                       , 1   ), new OreDictItemData(MT.Sn, U2));
		IL.IC2_Food_Can_Filled                  .set(ST.mkic("filledTinCan"                                 , 1, 0));
		IL.IC2_Food_Can_Spoiled                 .set(ST.mkic("filledTinCan"                                 , 1, 1));
		IL.IC2_Food_Can_Poisonous               .set(ST.mkic("filledTinCan"                                 , 1, 2));
		IL.IC2_Food_Can_Salmonella              .set(ST.mkic("filledTinCan"                                 , 1, 3));
		IL.IC2_Industrial_Diamond               .set(ST.mkic("industrialDiamond"                            , 1, 0), OP.gem.dat(MT.TECH.DiamondIndustrial));
		IL.IC2_Coal_Ball                        .set(ST.mkic("coalBall"                                     , 1   ), new OreDictItemData(MT.Coal, U*8));
		IL.IC2_Compressed_Coal_Ball             .set(ST.mkic("compressedCoalBall"                           , 1   ), new OreDictItemData(MT.Coal, U*8));
		IL.IC2_Compressed_Coal_Chunk            .set(ST.mkic("coalChunk"                                    , 1   ), new OreDictItemData(MT.Coal, U*64, MT.Obsidian, U*9));
		IL.IC2_Carbon_Fiber                     .set(ST.mkic("carbonFiber"                                  , 1   ));
		IL.IC2_Carbon_Mesh                      .set(ST.mkic("carbonMesh"                                   , 1   ));
		IL.IC2_Carbon_Plate                     .set(ST.mkic("carbonPlate"                                  , 1   ));
		IL.IC2_Advanced_Alloy                   .set(ST.mkic("advancedAlloy"                                , 1   ));
		IL.IC2_Iridium_Alloy                    .set(ST.mkic("iridiumPlate"                                 , 1   ), new OreDictItemData(MT.Ir, U*4, MT.Diamond, U*1));
		IL.IC2_Machine                          .set(ST.mkic("machine"                                      , 1   ), new OreDictItemData(ANY.Fe, U*8));
		IL.IC2_Machine_Adv                      .set(ST.mkic("advancedMachine"                              , 1   ), new OreDictItemData(ANY.Fe, U*8));
		IL.IC2_Generator                        .set(ST.mkic("generator"                                    , 1   ), new OreDictItemData(ANY.Fe, U*8));
		
		IL.IC2_SuBattery                        .set(ST.mkic("suBattery"                                    , 1   ));
		IL.IC2_ReBattery                        .set(ST.mkic("reBattery"                                    , 1   ));
		IL.IC2_EnergyCrystal                    .set(ST.mkic("energyCrystal"                                , 1   ), new OreDictItemData(MT.EnergiumRed, U*9));
		IL.IC2_LapotronCrystal                  .set(ST.mkic("lapotronCrystal"                              , 1   ), new OreDictItemData(MT.EnergiumRed, U*9));
		
		IL.Tool_Sword_Bronze                    .set(ST.mkic("bronzeSword"                                  , 1   ));
		IL.Tool_Pickaxe_Bronze                  .set(ST.mkic("bronzePickaxe"                                , 1   ));
		IL.Tool_Shovel_Bronze                   .set(ST.mkic("bronzeShovel"                                 , 1   ));
		IL.Tool_Axe_Bronze                      .set(ST.mkic("bronzeAxe"                                    , 1   ));
		IL.Tool_Hoe_Bronze                      .set(ST.mkic("bronzeHoe"                                    , 1   ));
		IL.IC2_WireCutter                       .set(ST.mkic("cutter"                                       , 1   ));
		
		IL.Credit_Iron                          .set(ST.mkic("coin"                                         , 1   ));
		
		IL.Upgrade_Overclocker                  .set(ST.mkic("overclockerUpgrade"                           , 1   ));
		IL.Upgrade_Battery                      .set(ST.mkic("energyStorageUpgrade"                         , 1   ));
		
		ArmorsGT.HAZMATS_FROST                  .add(ST.mkic("hazmatHelmet"                                 , 1, W));
		ArmorsGT.HAZMATS_FROST                  .add(ST.mkic("hazmatChestplate"                             , 1, W));
		ArmorsGT.HAZMATS_FROST                  .add(ST.mkic("hazmatLeggings"                               , 1, W));
		ArmorsGT.HAZMATS_FROST                  .add(ST.mkic("hazmatBoots"                                  , 1, W));
		ArmorsGT.HAZMATS_FROST                  .add(ST.make(MD.TF, "item.arcticHelm"                       , 1, W));
		ArmorsGT.HAZMATS_FROST                  .add(ST.make(MD.TF, "item.arcticPlate"                      , 1, W));
		ArmorsGT.HAZMATS_FROST                  .add(ST.make(MD.TF, "item.arcticLegs"                       , 1, W));
		ArmorsGT.HAZMATS_FROST                  .add(ST.make(MD.TF, "item.arcticBoots"                      , 1, W));
		ArmorsGT.HAZMATS_FROST                  .add(ST.make(MD.TF, "item.yetiHelm"                         , 1, W));
		ArmorsGT.HAZMATS_FROST                  .add(ST.make(MD.TF, "item.yetiPlate"                        , 1, W));
		ArmorsGT.HAZMATS_FROST                  .add(ST.make(MD.TF, "item.yetiLegs"                         , 1, W));
		ArmorsGT.HAZMATS_FROST                  .add(ST.make(MD.TF, "item.yetiBoots"                        , 1, W));
		
		ArmorsGT.HAZMATS_HEAT                   .add(ST.mkic("hazmatHelmet"                                 , 1, W));
		ArmorsGT.HAZMATS_HEAT                   .add(ST.mkic("hazmatChestplate"                             , 1, W));
		ArmorsGT.HAZMATS_HEAT                   .add(ST.mkic("hazmatLeggings"                               , 1, W));
		ArmorsGT.HAZMATS_HEAT                   .add(ST.mkic("hazmatBoots"                                  , 1, W));
		ArmorsGT.HAZMATS_HEAT                   .add(ST.make(MD.HBM, "item.asbestos_helmet"                 , 1, W));
		ArmorsGT.HAZMATS_HEAT                   .add(ST.make(MD.HBM, "item.asbestos_plate"                  , 1, W));
		ArmorsGT.HAZMATS_HEAT                   .add(ST.make(MD.HBM, "item.asbestos_legs"                   , 1, W));
		ArmorsGT.HAZMATS_HEAT                   .add(ST.make(MD.HBM, "item.asbestos_boots"                  , 1, W));
		
		ArmorsGT.HAZMATS_INSECTS                .add(ST.mkic("hazmatHelmet"                                 , 1, W));
		ArmorsGT.HAZMATS_INSECTS                .add(ST.mkic("hazmatChestplate"                             , 1, W));
		ArmorsGT.HAZMATS_INSECTS                .add(ST.mkic("hazmatLeggings"                               , 1, W));
		ArmorsGT.HAZMATS_INSECTS                .add(ST.mkic("hazmatBoots"                                  , 1, W));
		ArmorsGT.HAZMATS_INSECTS                .add(ST.make(MD.FR, "apiaristHelmet"                        , 1, W));
		ArmorsGT.HAZMATS_INSECTS                .add(ST.make(MD.FR, "apiaristChest"                         , 1, W));
		ArmorsGT.HAZMATS_INSECTS                .add(ST.make(MD.FR, "apiaristLegs"                          , 1, W));
		ArmorsGT.HAZMATS_INSECTS                .add(ST.make(MD.FR, "apiaristBoots"                         , 1, W));
		
		ArmorsGT.HAZMATS_BIO                    .add(ST.mkic("hazmatHelmet"                                 , 1, W));
		ArmorsGT.HAZMATS_BIO                    .add(ST.mkic("hazmatChestplate"                             , 1, W));
		ArmorsGT.HAZMATS_BIO                    .add(ST.mkic("hazmatLeggings"                               , 1, W));
		ArmorsGT.HAZMATS_BIO                    .add(ST.mkic("hazmatBoots"                                  , 1, W));
		ArmorsGT.HAZMATS_BIO                    .add(ST.make(MD.HBM, "item.hazmat_helmet"                   , 1, W));
		ArmorsGT.HAZMATS_BIO                    .add(ST.make(MD.HBM, "item.hazmat_plate"                    , 1, W));
		ArmorsGT.HAZMATS_BIO                    .add(ST.make(MD.HBM, "item.hazmat_legs"                     , 1, W));
		ArmorsGT.HAZMATS_BIO                    .add(ST.make(MD.HBM, "item.hazmat_boots"                    , 1, W));
		ArmorsGT.HAZMATS_BIO                    .add(ST.make(MD.HBM, "item.hazmat_paa_helmet"               , 1, W));
		ArmorsGT.HAZMATS_BIO                    .add(ST.make(MD.HBM, "item.hazmat_paa_plate"                , 1, W));
		ArmorsGT.HAZMATS_BIO                    .add(ST.make(MD.HBM, "item.hazmat_paa_legs"                 , 1, W));
		ArmorsGT.HAZMATS_BIO                    .add(ST.make(MD.HBM, "item.hazmat_paa_boots"                , 1, W));
		ArmorsGT.HAZMATS_BIO                    .add(ST.make(MD.ATSCI, "hazmat_helm"                        , 1, W));
		ArmorsGT.HAZMATS_BIO                    .add(ST.make(MD.ATSCI, "hazmat_chest"                       , 1, W));
		ArmorsGT.HAZMATS_BIO                    .add(ST.make(MD.ATSCI, "hazmat_legs"                        , 1, W));
		ArmorsGT.HAZMATS_BIO                    .add(ST.make(MD.ATSCI, "hazmat_boots"                       , 1, W));
		
		ArmorsGT.HAZMATS_CHEM                   .add(ST.mkic("hazmatHelmet"                                 , 1, W));
		ArmorsGT.HAZMATS_CHEM                   .add(ST.mkic("hazmatChestplate"                             , 1, W));
		ArmorsGT.HAZMATS_CHEM                   .add(ST.mkic("hazmatLeggings"                               , 1, W));
		ArmorsGT.HAZMATS_CHEM                   .add(ST.mkic("hazmatBoots"                                  , 1, W));
		ArmorsGT.HAZMATS_CHEM                   .add(ST.make(MD.HBM, "item.hazmat_helmet"                   , 1, W));
		ArmorsGT.HAZMATS_CHEM                   .add(ST.make(MD.HBM, "item.hazmat_plate"                    , 1, W));
		ArmorsGT.HAZMATS_CHEM                   .add(ST.make(MD.HBM, "item.hazmat_legs"                     , 1, W));
		ArmorsGT.HAZMATS_CHEM                   .add(ST.make(MD.HBM, "item.hazmat_boots"                    , 1, W));
		ArmorsGT.HAZMATS_CHEM                   .add(ST.make(MD.HBM, "item.hazmat_paa_helmet"               , 1, W));
		ArmorsGT.HAZMATS_CHEM                   .add(ST.make(MD.HBM, "item.hazmat_paa_plate"                , 1, W));
		ArmorsGT.HAZMATS_CHEM                   .add(ST.make(MD.HBM, "item.hazmat_paa_legs"                 , 1, W));
		ArmorsGT.HAZMATS_CHEM                   .add(ST.make(MD.HBM, "item.hazmat_paa_boots"                , 1, W));
		ArmorsGT.HAZMATS_CHEM                   .add(ST.make(MD.ATSCI, "hazmat_helm"                        , 1, W));
		ArmorsGT.HAZMATS_CHEM                   .add(ST.make(MD.ATSCI, "hazmat_chest"                       , 1, W));
		ArmorsGT.HAZMATS_CHEM                   .add(ST.make(MD.ATSCI, "hazmat_legs"                        , 1, W));
		ArmorsGT.HAZMATS_CHEM                   .add(ST.make(MD.ATSCI, "hazmat_boots"                       , 1, W));
		
		ArmorsGT.HAZMATS_GAS                    .add(ST.mkic("hazmatHelmet"                                 , 1, W));
		ArmorsGT.HAZMATS_GAS                    .add(ST.mkic("hazmatChestplate"                             , 1, W));
		ArmorsGT.HAZMATS_GAS                    .add(ST.mkic("hazmatLeggings"                               , 1, W));
		ArmorsGT.HAZMATS_GAS                    .add(ST.mkic("hazmatBoots"                                  , 1, W));
		ArmorsGT.HAZMATS_GAS                    .add(ST.make(MD.HBM, "item.hazmat_helmet"                   , 1, W));
		ArmorsGT.HAZMATS_GAS                    .add(ST.make(MD.HBM, "item.hazmat_plate"                    , 1, W));
		ArmorsGT.HAZMATS_GAS                    .add(ST.make(MD.HBM, "item.hazmat_legs"                     , 1, W));
		ArmorsGT.HAZMATS_GAS                    .add(ST.make(MD.HBM, "item.hazmat_boots"                    , 1, W));
		ArmorsGT.HAZMATS_GAS                    .add(ST.make(MD.HBM, "item.hazmat_paa_helmet"               , 1, W));
		ArmorsGT.HAZMATS_GAS                    .add(ST.make(MD.HBM, "item.hazmat_paa_plate"                , 1, W));
		ArmorsGT.HAZMATS_GAS                    .add(ST.make(MD.HBM, "item.hazmat_paa_legs"                 , 1, W));
		ArmorsGT.HAZMATS_GAS                    .add(ST.make(MD.HBM, "item.hazmat_paa_boots"                , 1, W));
		ArmorsGT.HAZMATS_GAS                    .add(ST.make(MD.ATSCI, "hazmat_helm"                        , 1, W));
		ArmorsGT.HAZMATS_GAS                    .add(ST.make(MD.ATSCI, "hazmat_chest"                       , 1, W));
		ArmorsGT.HAZMATS_GAS                    .add(ST.make(MD.ATSCI, "hazmat_legs"                        , 1, W));
		ArmorsGT.HAZMATS_GAS                    .add(ST.make(MD.ATSCI, "hazmat_boots"                       , 1, W));
		
		ArmorsGT.HAZMATS_RADIOACTIVE            .add(ST.mkic("hazmatHelmet"                                 , 1, W));
		ArmorsGT.HAZMATS_RADIOACTIVE            .add(ST.mkic("hazmatChestplate"                             , 1, W));
		ArmorsGT.HAZMATS_RADIOACTIVE            .add(ST.mkic("hazmatLeggings"                               , 1, W));
		ArmorsGT.HAZMATS_RADIOACTIVE            .add(ST.mkic("hazmatBoots"                                  , 1, W));
		ArmorsGT.HAZMATS_RADIOACTIVE            .add(ST.make(MD.ReC, "reactorcraft_item_hazhelmet"          , 1, W));
		ArmorsGT.HAZMATS_RADIOACTIVE            .add(ST.make(MD.ReC, "reactorcraft_item_hazchest"           , 1, W));
		ArmorsGT.HAZMATS_RADIOACTIVE            .add(ST.make(MD.ReC, "reactorcraft_item_hazlegs"            , 1, W));
		ArmorsGT.HAZMATS_RADIOACTIVE            .add(ST.make(MD.ReC, "reactorcraft_item_hazboots"           , 1, W));
		ArmorsGT.HAZMATS_RADIOACTIVE            .add(ST.make(MD.GC_GALAXYSPACE, "item.lead_helmet"          , 1, W));
		ArmorsGT.HAZMATS_RADIOACTIVE            .add(ST.make(MD.GC_GALAXYSPACE, "item.lead_plate"           , 1, W));
		ArmorsGT.HAZMATS_RADIOACTIVE            .add(ST.make(MD.GC_GALAXYSPACE, "item.lead_leg"             , 1, W));
		ArmorsGT.HAZMATS_RADIOACTIVE            .add(ST.make(MD.GC_GALAXYSPACE, "item.lead_boots"           , 1, W));
		ArmorsGT.HAZMATS_RADIOACTIVE            .add(ST.make(MD.TE_FOUNDATION, "armor.helmetLead"           , 1, W));
		ArmorsGT.HAZMATS_RADIOACTIVE            .add(ST.make(MD.TE_FOUNDATION, "armor.plateLead"            , 1, W));
		ArmorsGT.HAZMATS_RADIOACTIVE            .add(ST.make(MD.TE_FOUNDATION, "armor.legsLead"             , 1, W));
		ArmorsGT.HAZMATS_RADIOACTIVE            .add(ST.make(MD.TE_FOUNDATION, "armor.bootsLead"            , 1, W));
		ArmorsGT.HAZMATS_RADIOACTIVE            .add(ST.make(MD.HBM, "item.hazmat_helmet"                   , 1, W));
		ArmorsGT.HAZMATS_RADIOACTIVE            .add(ST.make(MD.HBM, "item.hazmat_plate"                    , 1, W));
		ArmorsGT.HAZMATS_RADIOACTIVE            .add(ST.make(MD.HBM, "item.hazmat_legs"                     , 1, W));
		ArmorsGT.HAZMATS_RADIOACTIVE            .add(ST.make(MD.HBM, "item.hazmat_boots"                    , 1, W));
		ArmorsGT.HAZMATS_RADIOACTIVE            .add(ST.make(MD.HBM, "item.hazmat_paa_helmet"               , 1, W));
		ArmorsGT.HAZMATS_RADIOACTIVE            .add(ST.make(MD.HBM, "item.hazmat_paa_plate"                , 1, W));
		ArmorsGT.HAZMATS_RADIOACTIVE            .add(ST.make(MD.HBM, "item.hazmat_paa_legs"                 , 1, W));
		ArmorsGT.HAZMATS_RADIOACTIVE            .add(ST.make(MD.HBM, "item.hazmat_paa_boots"                , 1, W));
		ArmorsGT.HAZMATS_RADIOACTIVE            .add(ST.make(MD.HBM, "item.paa_plate"                       , 1, W));
		ArmorsGT.HAZMATS_RADIOACTIVE            .add(ST.make(MD.HBM, "item.paa_legs"                        , 1, W));
		ArmorsGT.HAZMATS_RADIOACTIVE            .add(ST.make(MD.HBM, "item.paa_boots"                       , 1, W));
		ArmorsGT.HAZMATS_RADIOACTIVE            .add(ST.make(MD.ATSCI, "hazmat_helm"                        , 1, W));
		ArmorsGT.HAZMATS_RADIOACTIVE            .add(ST.make(MD.ATSCI, "hazmat_chest"                       , 1, W));
		ArmorsGT.HAZMATS_RADIOACTIVE            .add(ST.make(MD.ATSCI, "hazmat_legs"                        , 1, W));
		ArmorsGT.HAZMATS_RADIOACTIVE            .add(ST.make(MD.ATSCI, "hazmat_boots"                       , 1, W));
		
		ArmorsGT.HAZMATS_LIGHTNING              .add(ST.mkic("hazmatHelmet"                                 , 1, W));
		ArmorsGT.HAZMATS_LIGHTNING              .add(ST.mkic("hazmatChestplate"                             , 1, W));
		ArmorsGT.HAZMATS_LIGHTNING              .add(ST.mkic("hazmatLeggings"                               , 1, W));
		ArmorsGT.HAZMATS_LIGHTNING              .add(ST.mkic("hazmatBoots"                                  , 1, W));
		ArmorsGT.HAZMATS_LIGHTNING              .add(ST.make(Items.chainmail_helmet                         , 1, W));
		ArmorsGT.HAZMATS_LIGHTNING              .add(ST.make(Items.chainmail_chestplate                     , 1, W));
		ArmorsGT.HAZMATS_LIGHTNING              .add(ST.make(Items.chainmail_leggings                       , 1, W));
		ArmorsGT.HAZMATS_LIGHTNING              .add(ST.make(Items.chainmail_boots                          , 1, W));
	}
}
